@@ -724,7 +724,7 @@ dans la prambule")
 ("keyboard" "clavier")
 ("keyboard equivalent" "raccourci clavier")
 ("keyboard modifiers" "modificateurs de clavier")
-("keyboard shorthand" "raccourci clavier")
+("keyboard shortcut" "raccourci clavier")
 ("keymaps" "claviers")
 ("keyword" "mot-clef")
 ("keywords" "mots-clefs")
