@@ -665,7 +665,7 @@
 ("justify text" "poravnaj besedilo obojestransko")
 ("keyboard equivalent" "ekvivalent na tipkovnici")
 ("keyboard modifiers" "modifikator tipkovnice")
-("keyboard shorthand" "okrajava na tipkovnici")
+("keyboard shortcut" "okrajava na tipkovnici")
 ("keyboard" "tipkovnica")
 ("keymaps" "razporeditve tipk")
 ("key" "tipka")
