@@ -5,16 +5,14 @@
 ;; DESCRIPTION : routines for on-the-fly evaluation of scripts
 ;; COPYRIGHT   : (C) 2005  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (dynamic scripts-menu)
-  (:use (dynamic scripts-edit)
-	(utils plugins plugin-cmd)))
+  (:use (dynamic scripts-edit)))
 
 (menu-bind scripts-eval-menu
   (when (script-evaluable?)
