@@ -78,14 +78,25 @@
 ;; Scheme sessions
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define (replace-newline s)
+  (with l (string-tokenize-by-char s #\newline)
+    (if (<= (length l) 1) s
+	(tm->tree `(document ,@l)))))
+
 (define (var-object->string t)
   (with s (object->string t)
-    (if (== s "#<unspecified>") "" s)))
+    (if (== s "#<unspecified>") "" (replace-newline (string-encode s)))))
+
+(define (eval-string-with-catch s)
+  (catch #t
+	 (lambda () (eval (string->object s)))
+	 (lambda (key msg . args)
+	   key)))
 
 (tm-define (scheme-eval t)
   (let* ((s (texmacs->verbatim (tm->tree t)))
-	 (r (eval (string->object s))))
-    (cond ((and (tree? r) (session-scheme-trees?)) r)
+	 (r (eval-string-with-catch s)))
+    (cond ((and (tree? r) (session-scheme-trees?)) (tree-copy r))
 	  ((session-scheme-math?)
 	   (with m (cas->stree r)
 	     (if (tm? m) (tree 'math (tm->tree m)) (var-object->string r))))
@@ -284,7 +295,11 @@
 	 (tree-remove! t 2 1))
 	((or (tm-func? t 'folded-io-math) (tm-func? t 'unfolded-io-math))
 	 (tree-assign-node! t 'input-math)
-	 (tree-remove! t 2 1))))
+	 (tree-remove! t 2 1))
+	((tm-func? t 'output)
+	 (with p (tree-ref t :up)
+	   (when (tree-is? p 'document)
+	     (tree-remove! p (tree-index t) 1))))))
 
 (define (field-update-math t)
   (if (session-math-input?)
@@ -545,8 +560,9 @@
   (with-innermost t field-input-context?
     (let* ((lan (get-env "prog-language"))
 	   (ses (get-env "prog-session"))
-	   (p (plugin-prompt lan ses)))
-      (tree-go-to (field-create t p forwards?) 1 :end))))
+	   (p (plugin-prompt lan ses))
+	   (t (field-create t p forwards?)))
+      (tree-go-to t 1 :end))))
 
 (tm-define (field-insert-text forward?)
   (with-innermost t field-input-context?
