@@ -5,10 +5,9 @@
 ;; DESCRIPTION : This is the standard TeXmacs initialization file
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -31,7 +30,9 @@
 ;; (set! primitive-load new-primitive-load)
 
 ;(display "Booting TeXmacs kernel functionality\n")
-(load (url-concretize "$TEXMACS_PATH/progs/kernel/boot/boot.scm"))
+(if (os-mingw?)
+    (load "kernel/boot/boot.scm")
+    (load (url-concretize "$TEXMACS_PATH/progs/kernel/boot/boot.scm")))
 (inherit-modules (kernel boot compat) (kernel boot abbrevs)
 		 (kernel boot debug) (kernel boot srfi)
 		 (kernel boot ahash-table) (kernel boot prologue))
@@ -127,6 +128,7 @@
 (lazy-keyboard (dynamic scripts-kbd) always?)
 (lazy-menu (dynamic format-prog-menu) prog-format-menu prog-format-icons)
 (lazy-menu (dynamic fold-menu) insert-fold-menu)
+(lazy-define (dynamic session-edit) scheme-eval)
 (lazy-menu (dynamic session-menu) insert-session-menu
 	   session-menu session-icons session-help-icons help-icons)
 (lazy-menu (dynamic scripts-menu) scripts-eval-menu
