@@ -5,10 +5,9 @@
 ;; DESCRIPTION : setup key combinations for frequently used commands
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -16,6 +15,7 @@
   (:use
     (utils edit auto-close)
     (generic format-edit)
+    (generic generic-edit)
     (text std-text-edit)))
 
 (kbd-symbols
@@ -36,7 +36,10 @@
   "Mu" "Nu" "Xi" "Omicron" "Pi" "Rho"
   "Sigma" "Tau" "Upsilon" "Phi" "Chi" "Psi" "Omega"
   "grave" "acute" "check" "breve" "bar"
-  "cedille" "sz" "ae" "oe" "AE" "OE"
+  "cedille"
+  "AA" "AE" "DH" "L" "NG" "O" "OE" "S" "SS" "TH"
+  "aa" "ae" "dh" "dj" "i" "j" "l" "ng" "o" "oe" "ss" "sz" "th"
+
   "ast" "asterisk"
   
   "cdot" "times" "asterisk" "div" "diamond"
@@ -375,7 +378,7 @@
   ("medskip" "Insert medium vertical space" (make-vspace-after "1fn"))
   ("bigskip" "Insert big vertical space" (make-vspace-after "2fn"))
   ("item" "Insert new item or number" (make-item))
-  ("label" "Make label" (make 'label))
+  ("label" "Make label" (make-label))
   ("ref" "Make reference" (make 'reference))
   ("pageref" "Make page reference" (make 'pageref))
   ("footnote" "Insert a footnote" (make 'footnote))
