@@ -5,10 +5,9 @@
 ;; DESCRIPTION : routines for trees and for modifying documents
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -281,6 +280,11 @@
   (with p (apply tree->path (cons t l))
     (if p (go-to p))))
 
+(tm-define (tree-cursor-at? t . l)
+  (:synopsis "Is the cursor at the position determined by @l inside @t?")
+  (with p (apply tree->path (cons t l))
+    (== (cursor-path) p)))
+
 (tm-define (tree-select t . l)
   (:synopsis "Select the tree @(tree-ref t . l)")
   (with t (apply tree-ref (cons t l))
