@@ -20,6 +20,27 @@ static bool textm_appendices= false;
 static bool textm_unicode   = false;
 static bool textm_natbib    = false;
 
+/*
+bool
+check_tree (tree t) {
+  if (is_atomic (t)) {
+    for (int i=0; i<N(t->label); i++)
+      if (((int) t->label[i]) == 0) {
+	cout << "t= " << t << "\n";
+	return true;
+      }
+  }
+  else {
+    for (int i=0; i<N(t); i++)
+      if (check_tree (t[i])) {
+	if (is_atomic (t[i])) cout << "t= " << t << "\n";
+	return true;
+      }
+  }
+  return false;
+}
+*/
+
 /******************************************************************************
 * Preprocess preamble
 ******************************************************************************/
@@ -408,7 +429,8 @@ is_right_type (tree t) {
 
 static bool
 is_large_delimiter (tree t, int& type) {
-  if ((!is_tuple (t)) || (N(t) != 2) || is_compound (t[0])) return false;
+  if ((!is_tuple (t)) || (N(t) != 2) ||
+      is_compound (t[0]) || is_compound (t[1])) return false;
   string s= t[0]->label;
   if (starts (s, "\\Big")) s= "\\big" * s(4,N(s));
   if (starts (s, "\\bigg")) s= "\\big" * s(5,N(s));
@@ -557,31 +579,33 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\mathit", 1)) return var_m2e (t, MATH_FONT_FAMILY, "it");
   if (is_tuple (t, "\\mathsl", 1)) return var_m2e (t, MATH_FONT_FAMILY, "sl");
   if (is_tuple (t, "\\mathup", 1)) return var_m2e (t, MATH_FONT_FAMILY, "up");
-  if (is_tuple (t, "\\mathcal", 1))  return m2e (t, MATH_FONT, "cal");
+  if (is_tuple (t, "\\mathcal", 1)) return m2e (t, MATH_FONT, "cal");
   if (is_tuple (t, "\\mathfrak", 1)) return m2e (t, MATH_FONT, "Euler");
-  if (is_tuple (t, "\\mathbb", 1))   return m2e (t, MATH_FONT, "Bbb");
-  if (is_tuple (t, "\\mathbbm", 1))   return m2e (t, MATH_FONT, "Bbb*");
+  if (is_tuple (t, "\\mathbb", 1)) return m2e (t, MATH_FONT, "Bbb");
+  if (is_tuple (t, "\\mathbbm", 1)) return m2e (t, MATH_FONT, "Bbb*");
 
-  if (is_tuple (t, "\\prime", 1))  return tree (RPRIME, string_arg (t[1]));
-  if (is_tuple (t, "\\frac", 2))  return tree (FRAC, l2e (t[1]), l2e (t[2]));
+  if (is_tuple (t, "\\prime", 1)) return tree (RPRIME, string_arg (t[1]));
+  if (is_tuple (t, "\\frac", 2)) return tree (FRAC, l2e (t[1]), l2e (t[2]));
+  if (is_tuple (t, "\\atop", 2))
+    return compound ("atop", l2e (t[1]), l2e (t[2]));
   if (is_tuple (t, "\\sqrt", 1))  return tree (SQRT, l2e (t[1]));
   if (is_tuple (t, "\\sqrt*", 2)) return tree (SQRT, l2e (t[2]), l2e (t[1]));
   if (is_tuple (t, "\\<sub>", 1)) return tree (RSUB, l2e (t[1]));
-  if (is_tuple (t, "\\not", 1))   return tree (NEG, l2e (t[1]));
-  if (is_tuple (t, "\\bar", 1))  return tree (WIDE, l2e (t[1]), "<bar>");
-  if (is_tuple (t, "\\hat", 1))  return tree (WIDE, l2e (t[1]), "^");
-  if (is_tuple (t, "\\tilde", 1))  return tree (WIDE, l2e (t[1]), "~");
-  if (is_tuple (t, "\\widehat", 1))  return tree (WIDE, l2e (t[1]), "^");
-  if (is_tuple (t, "\\widetilde", 1))  return tree (WIDE, l2e (t[1]), "~");
-  if (is_tuple (t, "\\dot", 1))  return tree (WIDE, l2e (t[1]), "<dot>");
-  if (is_tuple (t, "\\ddot", 1))  return tree (WIDE, l2e (t[1]), "<ddot>");
-  if (is_tuple (t, "\\dddot", 1))  return tree (WIDE, l2e (t[1]), "<dddot>");
-  if (is_tuple (t, "\\ddddot", 1))  return tree (WIDE, l2e (t[1]), "<ddddot>");
-  if (is_tuple (t, "\\check", 1))  return tree (WIDE, l2e (t[1]), "<check>");
-  if (is_tuple (t, "\\grave", 1))  return tree (WIDE, l2e (t[1]), "<grave>");
-  if (is_tuple (t, "\\acute", 1))  return tree (WIDE, l2e (t[1]), "<acute>");
-  if (is_tuple (t, "\\vec", 1))  return tree (WIDE, l2e (t[1]), "<vect>");
-  if (is_tuple (t, "\\breve", 1))  return tree (WIDE, l2e (t[1]), "<breve>");
+  if (is_tuple (t, "\\not", 1)) return tree (NEG, l2e (t[1]));
+  if (is_tuple (t, "\\bar", 1)) return tree (WIDE, l2e (t[1]), "<bar>");
+  if (is_tuple (t, "\\hat", 1)) return tree (WIDE, l2e (t[1]), "^");
+  if (is_tuple (t, "\\tilde", 1)) return tree (WIDE, l2e (t[1]), "~");
+  if (is_tuple (t, "\\widehat", 1)) return tree (WIDE, l2e (t[1]), "^");
+  if (is_tuple (t, "\\widetilde", 1)) return tree (WIDE, l2e (t[1]), "~");
+  if (is_tuple (t, "\\dot", 1)) return tree (WIDE, l2e (t[1]), "<dot>");
+  if (is_tuple (t, "\\ddot", 1)) return tree (WIDE, l2e (t[1]), "<ddot>");
+  if (is_tuple (t, "\\dddot", 1)) return tree (WIDE, l2e (t[1]), "<dddot>");
+  if (is_tuple (t, "\\ddddot", 1)) return tree (WIDE, l2e (t[1]), "<ddddot>");
+  if (is_tuple (t, "\\check", 1)) return tree (WIDE, l2e (t[1]), "<check>");
+  if (is_tuple (t, "\\grave", 1)) return tree (WIDE, l2e (t[1]), "<grave>");
+  if (is_tuple (t, "\\acute", 1)) return tree (WIDE, l2e (t[1]), "<acute>");
+  if (is_tuple (t, "\\vec", 1)) return tree (WIDE, l2e (t[1]), "<vect>");
+  if (is_tuple (t, "\\breve", 1)) return tree (WIDE, l2e (t[1]), "<breve>");
   if (is_tuple (t, "\\abovering", 1))
     return tree (WIDE, l2e (t[1]), "<abovering>");
   if (is_tuple (t, "\\hspace", 1) || is_tuple (t, "\\hspace*", 1)) {
@@ -592,7 +616,7 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\vspace", 1) || is_tuple (t, "\\vspace*", 1))
     return tree (VSPACE, t2e (t[1]));
   if (is_tuple (t, "\\label", 1)) return tree (LABEL, t2e (t[1]));
-  if (is_tuple (t, "\\ref", 1))   return tree (REFERENCE, t2e (t[1]));
+  if (is_tuple (t, "\\ref", 1)) return tree (REFERENCE, t2e (t[1]));
   if (is_tuple (t, "\\mathop", 1)) return l2e (t[1]);
   if (is_tuple (t, "\\mathrel", 1)) return l2e (t[1]);
   if (is_tuple (t, "\\overbrace", 1))
