@@ -4,10 +4,9 @@
 * DESCRIPTION: upgrade old TeXmacs formats
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "convert.hpp"
@@ -2769,6 +2768,43 @@ upgrade_mmx (tree t) {
   }
 }
 
+/******************************************************************************
+* Upgrade sessions
+******************************************************************************/
+
+static tree
+upgrade_session (tree t, tree lan, tree ses) {
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "session", 1))
+    return compound ("session", copy (lan), copy (ses),
+		     upgrade_session (t[0], lan, ses));
+  else if (is_func (t, WITH, 5) &&
+	   t[0] == PROG_LANGUAGE &&
+	   t[2] == PROG_SESSION)
+    return upgrade_session (t[4], t[1], t[3]);
+  else {
+    int i, n= N(t);
+    tree r (L(t));
+    for (i=0; i<n; i++) {
+      if (is_document (t) && is_compound (t[i], "input", 2)) {
+	bool m = is_compound (t[i][1], "math", 1);
+	tree in= (m? t[i][1][0]: t[i][1]);
+	if ((i+1)<n && is_compound (t[i+1], "output", 1)) {
+	  const char* op= (m? "unfolded-io-math": "unfolded-io");
+	  r << compound (op, t[i][0], in, t[i+1][0]);
+	  i++;
+	}
+	else {
+	  const char* op= (m? "input-math": "input");
+	  r << compound (op, t[i][0], in);
+	}
+      }
+      else r << upgrade_session (t[i], lan, ses);
+    }
+    return r;
+  }
+}
+
 /******************************************************************************
 * Upgrade from previous versions
 ******************************************************************************/
@@ -2883,5 +2919,7 @@ upgrade (tree t, string version) {
     t= upgrade_scheme_doc (t);
   if (version_inf_eq (version, "1.0.6.14"))
     t= upgrade_mmx (t);
+  if (version_inf_eq (version, "1.0.7.1"))
+    t= upgrade_session (t, "scheme", "default");
   return t;
 }
