@@ -4,10 +4,9 @@
 * DESCRIPTION: conversion of xml and html strings into logical html trees
 * COPYRIGHT  : (C) 2000  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "convert.hpp"
@@ -308,7 +307,7 @@ xml_html_parser::expand_entities (string s) {
       int start= i++;
       if (i<n && s[i] == '#') {
 	i++;
-	if (i<n && s[i] == 'x' || s[i] == 'X') {
+	if (i<n && (s[i] == 'x' || s[i] == 'X')) {
 	  i++;
 	  while (i<n && is_hex_digit (s[i])) i++;
 	}
