@@ -4,16 +4,16 @@
 * DESCRIPTION: abstract cursor handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "tree_cursor.hpp"
 #include "drd_std.hpp"
 #include "drd_mode.hpp"
 #include "analyze.hpp"
+#include "vars.hpp"
 
 /******************************************************************************
 * Finding a closest cursor inside a tree
@@ -26,7 +26,7 @@ is_inside (tree t, path p) {
     string s= t->label;
     int i, n= N(s), k= p->item;
     if (!is_atom (p) || k<0 || k>n) return false;
-    for (i=0; i<k; tm_char_forwards (s, i));
+    for (i=0; i<k; tm_char_forwards (s, i)) {}
     return i == k;
   }
   else if (is_atom (p)) return p->item == 0 || p->item == 1;
@@ -42,7 +42,7 @@ closest_inside (tree t, path p) {
   else if (is_atomic (t)) {
     string s= t->label;
     int i, n= N(s), k= max (0, min (n, p->item));
-    for (i=0; i<k; tm_char_forwards (s, i));
+    for (i=0; i<k; tm_char_forwards (s, i)) {}
     return i;
   }
   else if (is_atom (p) || p->item < 0 || p->item >= N(t))
@@ -88,7 +88,7 @@ is_accessible_cursor (tree t, path p) {
     return is_modified_accessible (t, p, false, true);
   default:
     if (!the_drd->is_accessible_child (t, p->item)) return false;
-    else if (the_drd->get_mode_child (t, p->item, MODE_PARENT) == MODE_SRC) {
+    else if (the_drd->get_env_child (t, p->item, MODE, "") == "src") {
       int old_mode= set_access_mode (DRD_ACCESS_SOURCE);
       bool r= is_accessible_cursor (t[p->item], p->next);
       set_access_mode (old_mode);
@@ -121,7 +121,7 @@ closest_accessible (tree t, path p) {
     int i, k= p->item, n= N(t);
     if (p == 1) k= max (0, n-1);
     for (i=0; i<n; i++) {
-      int j= (i&1 == 0? (k+(i>>1) % n): (k+n-((i+1)>>1) % n));
+      int j= ((i&1) == 0? (k+(i>>1) % n): (k+n-((i+1)>>1) % n));
       if (the_drd->is_accessible_child (t, j)) {
 	// FIXME: certain tags modify source accessability props
 	// FIXME: cells with non-trivial span may lead to unaccessability
@@ -134,6 +134,7 @@ closest_accessible (tree t, path p) {
       return path ();
     }
   }
+  return path ();
 }
 
 bool
@@ -162,7 +163,7 @@ bool
 valid_cursor (tree t, path p, bool start_flag) {
   if ((!is_nil (p)) && (!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] testing valid cursor " << p << " in " << t << "\n";
-    fatal_error ("bad path", "valid_cursor", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   if (is_nil (p)) return false;
@@ -188,7 +189,7 @@ pre_correct (tree t, path p) {
   // cout << "Precorrect " << p << " in " << t << "\n";
   if ((!is_nil (p)) && (!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] precorrecting " << p << " in " << t << "\n";
-    fatal_error ("bad path", "pre_correct", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   if (is_nil (p)) return pre_correct (t, path(0));
@@ -228,11 +229,10 @@ pre_correct (tree t, path p) {
 
 static bool
 left_most (tree t, path p) {
-  if (is_nil (p))
-    fatal_error ("invalid nil path", "left_most", "tree_cursor.cpp");
+  if (is_nil (p)) FAILED ("invalid nil path");
   if ((!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] left most " << p << " in " << t << "\n";
-    fatal_error ("bad path", "left_most", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   int i=p->item;
@@ -243,11 +243,10 @@ left_most (tree t, path p) {
 
 static path
 left_correct (tree t, path p) {
-  if (is_nil (p))
-    fatal_error ("invalid nil path", "left_correct", "tree_cursor.cpp");
+  if (is_nil (p)) FAILED ("invalid nil path");
   if ((!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] left correcting " << p << " in " << t << "\n";
-    fatal_error ("bad path", "left_correct", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   int i=p->item;
@@ -260,11 +259,10 @@ left_correct (tree t, path p) {
 
 static bool
 right_most (tree t, path p) {
-  if (is_nil (p))
-    fatal_error ("invalid nil path", "right_most", "tree_cursor.cpp");
+  if (is_nil (p)) FAILED ("invalid nil path");
   if ((!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] right most " << p << " in " << t << "\n";
-    fatal_error ("bad path", "right_most", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   int i=p->item;
@@ -275,11 +273,10 @@ right_most (tree t, path p) {
 
 static path
 right_correct (tree t, path p) {
-  if (is_nil (p))
-    fatal_error ("invalid nil path", "right_correct", "tree_cursor.cpp");
+  if (is_nil (p)) FAILED ("invalid nil path");
   if ((!is_atom (p)) && ((p->item < 0) || (p->item >= arity (t)))) {
     cerr << "TeXmacs] right correcting " << p << " in " << t << "\n";
-    fatal_error ("bad path", "right_correct", "tree_cursor.cpp");
+    FAILED ("bad path");
   }
 
   int i=p->item;
@@ -331,8 +328,8 @@ super_correct (tree t, path p) {
   path q= path_up (p);
   path r= up_correct (t, q);
   if (q != r) {
-    if (is_nil (r)) fatal_error ("Unexpected situation", "super_correct");
-    else if (is_atomic (subtree (t, r))) p= path_up (r) * 0;
+    ASSERT (!is_nil (r), "unexpected situation");
+    if (is_atomic (subtree (t, r))) p= path_up (r) * 0;
     else p= r * 0;
   }
   return correct_cursor (t, p);
