@@ -21,6 +21,7 @@
 #endif // EXPERIMENTAL
 
 //box empty_box (path ip, int x1=0, int y1=0, int x2=0, int y2=0);
+bool enable_fastenv= false;
 
 /******************************************************************************
 * Contructors, destructors and notification of modifications
@@ -182,6 +183,7 @@ edit_typeset_rep::typeset_invalidate_env () {
 
 void
 edit_typeset_rep::typeset_exec_until (path p) {
+  //time_t t1= texmacs_time ();
   if (has_changed (THE_TREE + THE_ENVIRONMENT))
     if (p != correct_cursor (et, rp * 0)) {
       if (DEBUG_STD)
@@ -192,8 +194,26 @@ edit_typeset_rep::typeset_exec_until (path p) {
   if (N(cur)>=25) // avoids out of memory in weird cases
     typeset_invalidate_env ();
   typeset_prepare ();
-  exec_until (ttt, p - rp);
+  if (enable_fastenv) {
+    tree t= subtree (et, rp);
+    path q= path_up (p / rp);
+    while (!is_nil (q)) {
+      int i= q->item;
+      tree w= drd->get_env_child (t, i, tree (WITH));
+      if (w == "") break;
+      //cout << "w= " << w << "\n";
+      for (int j=0; j<N(w); j+=2) {
+	//cout << w[j] << " := " << env->exec (w[j+1]) << "\n";
+	env->write (w[j]->label, env->exec (w[j+1]));
+      }
+      t= t[i];
+      q= q->next;
+    }
+  }
+  else exec_until (ttt, p / rp);
   env->read_env (cur (p));
+  //time_t t2= texmacs_time ();
+  //if (t2 - t1 >= 10) cout << "typeset_exec_until took " << t2-t1 << "ms\n";
 }
 
 bool
@@ -426,7 +446,7 @@ edit_typeset_rep::init_style (string name) {
   if ((name == "none") || (name == "") || (name == "style")) the_style= TUPLE;
   else if (arity (the_style) == 0) the_style= tree (TUPLE, name);
   else the_style= tree (TUPLE, name) * the_style (1, N(the_style));
-  buf->need_save= buf->need_autosave= true;
+  require_save ();
   notify_change (THE_ENVIRONMENT);
 }
 
@@ -438,7 +458,7 @@ edit_typeset_rep::init_add_package (string name) {
       return;
 
   the_style << tree (name);
-  buf->need_save= buf->need_autosave= true;
+  require_save ();
   notify_change (THE_ENVIRONMENT);
 }
 
@@ -448,7 +468,7 @@ edit_typeset_rep::init_remove_package (string name) {
   tree new_style= tree (TUPLE);
   for (i=0; i<n; i++)
     if (the_style[i] == name) {
-      buf->need_save= buf->need_autosave= true;
+      require_save ();
       notify_change (THE_ENVIRONMENT);
     }
     else new_style << the_style[i];
@@ -475,24 +495,29 @@ edit_typeset_rep::init_default (string var) {
 
 void
 edit_typeset_rep::typeset (SI& x1, SI& y1, SI& x2, SI& y2) {
+  //time_t t1= texmacs_time ();
   typeset_prepare ();
   eb= empty_box (reverse (rp));
   // saves memory, also necessary for change_log update
   bench_start ("typeset");
   eb= ::typeset (ttt, x1, y1, x2, y2);
   bench_end ("typeset");
+  //time_t t2= texmacs_time ();
+  //if (t2 - t1 >= 12) cout << "typeset took " << t2-t1 << "ms\n";
 }
 
 void
 edit_typeset_rep::typeset_invalidate (path p) {
   if (rp <= p) {
+    //cout << "Invalidate " << p << "\n";
     notify_change (THE_TREE);
-    ::notify_assign (ttt, p-rp, subtree (et, p));
+    ::notify_assign (ttt, p / rp, subtree (et, p));
   }
 }
 
 void
 edit_typeset_rep::typeset_invalidate_all () {
+  //cout << "Invalidate all\n";
   notify_change (THE_ENVIRONMENT);
   typeset_preamble ();
   ::notify_assign (ttt, path(), subtree (et, rp));
