@@ -336,7 +336,7 @@ edit_interface_rep::set_hybrid_footer (tree st) {
 * Update footer
 ******************************************************************************/
 
-DEBUG
+TM_DEBUG
 (
   int concrete_count = 0;
   int abstract_count = 0;
@@ -354,7 +354,7 @@ DEBUG
 
 void
 edit_interface_rep::set_footer () {
-  DEBUG
+  TM_DEBUG
   (
     cout << "--------------------------------------------------------------\n";
     cout << "concrete  " << concrete_count << "\n";
@@ -380,8 +380,10 @@ edit_interface_rep::set_footer () {
     set_right_footer();
   }
   else {
-    set_left_footer (message_l);
-    set_right_footer (message_r);
+    if (message_l == "") set_left_footer ();
+    else set_left_footer (message_l);
+    if (message_r == "") set_right_footer ();
+    else set_right_footer (message_r);
     message_l= message_r= "";
   }
 }
@@ -392,6 +394,7 @@ edit_interface_rep::set_footer () {
 
 void
 edit_interface_rep::set_message (string l, string r, bool temp) {
+  eval ("(set-message-notify)");
   message_l= l;
   message_r= r;
   if (!temp) {
