@@ -4,10 +4,9 @@
 * DESCRIPTION: graphics between the editor and the window manager
 * COPYRIGHT  : (C) 2003  Joris van der Hoeven and Henri Lesourd
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Interface/edit_graphics.hpp"
@@ -39,7 +38,7 @@ edit_graphics_rep::inside_graphics (bool b) {
   tree st  = et;
   while (!is_nil (p)) {
     if (is_func (st, GRAPHICS)) flag= true;
-    if (b && is_func (st, TEXT_AT )) flag= false;
+    if (b && is_func (st, TEXT_AT)) flag= false;
     st= st[p->item];
     p = p->next;
   }
@@ -156,8 +155,8 @@ edit_graphics_rep::adjust (point p) {
 	int n= N(sels);
 	for (i=0; i<n; i++) {
 	  point sp= sels[i]->p;
-	  if (N(res)==0 || N(sp)>0 && norm (fp - sp) < 5*get_pixel_size ()
-				   && norm (fp - sp) < norm (fp - res))
+	  if (N(res)==0 || (N(sp)>0 && norm (fp - sp) < 5*get_pixel_size ()
+			            && norm (fp - sp) < norm (fp - res)))
 	    res= sels[i]->p;
 	}
       }
