@@ -32,8 +32,8 @@ protected:
   time_t        next_animate;  // time for next animation
   bool          full_screen;   // full screen mode ?
   bool          got_focus;     // do we have keyboard focus ?
-  string        sh_s;          // current string for shorthands
-  int           sh_len;        // length of translation
+  string        sh_s;          // current string for shortcuts
+  double        sh_mark;       // 0 or mark for undoing shortcut
   widget        popup_win;     // the current popup window
   string        message_l;     // a left message to display
   string        message_r;     // a right message to display
@@ -126,6 +126,7 @@ public:
   bool in_replace_mode ();
   bool in_spell_mode ();
   bool kbd_get_command (string which, string& help, command& cmd);
+  void interrupt_shortcut ();
   bool try_shortcut (string comb);
   void key_press (string key);
   void emulate_keyboard (string keys, string action= "");
