@@ -4,10 +4,9 @@
 * DESCRIPTION: Messages to and between widgets
 * COPYRIGHT  : (C) 2007  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef MESSAGE_H
@@ -22,7 +21,7 @@
 * Slots should really be defined in message.hpp
 ******************************************************************************/
 
-typedef enum slot_id {
+enum slot_id {
   SLOT_IDENTIFIER,
   SLOT_WINDOW,
   SLOT_RENDERER,
@@ -84,10 +83,12 @@ public:
   inline bool operator != (slot_id sid2) { return sid != sid2; }
   inline bool operator == (slot s) { return sid == s.sid; }
   inline bool operator != (slot s) { return sid != s.sid; }
-  inline friend ostream& operator << (ostream& out, slot s) {
+  inline friend tm_ostream& operator << (tm_ostream& out, slot s) {
     return out << s.sid; }
 };
 
+const char * slot_name (const slot s);
+
 //extern bool* slot_state_table;
 //inline bool is_state_slot (slot s) { return slots_state_table[s]; }
 
@@ -119,7 +120,7 @@ send (widget w, slot s, T1 val1, T2 val2, T3 val3) {
 
 template<class T1, class T2, class T3, class T4> void
 send (widget w, slot s, T1 val1, T2 val2, T3 val3, T4 val4) {
-  typedef quadruple<T1,T2,T3,T4> T;
+  typedef quartet<T1,T2,T3,T4> T;
   w->send (s, close_box<T> (T (val1, val2, val3, val4)));
 }
 
@@ -150,7 +151,7 @@ query (widget w, slot s, T1& val1, T2& val2, T3& val3) {
 
 template<class T1, class T2, class T3, class T4> void
 query (widget w, slot s, T1& val1, T2& val2, T3& val3, T4& val4) {
-  typedef quadruple<T1,T2,T3,T4> T;
+  typedef quartet<T1,T2,T3,T4> T;
   T q= open_box<T> (w->query (s, type_helper<T>::id));
   val1= q.x1; val2= q.x2; val3= q.x3; val4= q.x4;
 }
