@@ -16,6 +16,7 @@
 #include "connect.hpp"
 #include "convert.hpp"
 #include "file.hpp"
+#include "image_files.hpp"
 #include "sys_utils.hpp"
 #include "tmfs.hpp"
 #include "client_server.hpp"
@@ -31,6 +32,8 @@
 #include "Bibtex/bibtex.hpp"
 #include "link.hpp"
 #include "dictionary.hpp"
+#include "patch.hpp"
+#include "grammar.hpp"
 #include <string.h>
 #include <libguile.h>
 
@@ -47,6 +50,10 @@ extern void initialize_glue_basic ();
 extern void initialize_glue_editor ();
 extern void initialize_glue_server ();
 
+/******************************************************************************
+* Miscellaneous routines for use by glue only
+******************************************************************************/
+
 string
 scheme_dialect () {
 #ifdef GUILE_A
@@ -94,7 +101,7 @@ gui_is_qt () {
 
 bool
 os_win32 () {
-#ifdef OS_WIN32
+#if defined (OS_WIN32)
   return true;
 #else
   return false;
@@ -103,7 +110,7 @@ os_win32 () {
 
 bool
 os_mingw () {
-#ifdef __MINGW32__
+#if defined (__MINGW__) || defined (__MINGW32__)
   return true;
 #else
   return false;
@@ -116,6 +123,18 @@ win32_display (string s) {
   cout.flush ();
 }
 
+void
+tm_output (string s) {
+  cout << s;
+  cout.flush ();
+}
+
+void
+tm_errput (string s) {
+  cerr << s;
+  cerr.flush ();
+}
+
 #ifdef GUILE_C
 #define SET_SMOB(smob,data,type)   \
   SCM_NEWSMOB (smob, SCM_UNPACK (type), data);
@@ -393,11 +412,11 @@ tree
 tree_assign (tree r, tree t) {
   path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    assign (reverse (ip), t);
+    assign (reverse (ip), copy (t));
     return subtree (the_et, reverse (ip));
   }
   else {
-    assign (r, t);
+    assign (r, copy (t));
     return r;
   }
 }
@@ -406,11 +425,11 @@ tree
 tree_insert (tree r, int pos, tree t) {
   path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    insert (reverse (path (pos, ip)), t);
+    insert (reverse (path (pos, ip)), copy (t));
     return subtree (the_et, reverse (ip));
   }
   else {
-    insert (r, pos, t);
+    insert (r, pos, copy (t));
     return r;
   }
 }
@@ -471,11 +490,11 @@ tree
 tree_insert_node (tree r, int pos, tree t) {
   path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    insert_node (reverse (path (pos, ip)), t);
+    insert_node (reverse (path (pos, ip)), copy (t));
     return subtree (the_et, reverse (ip));
   }
   else {
-    insert_node (r, pos, t);
+    insert_node (r, pos, copy (t));
     return r;
   }
 }
