@@ -4,14 +4,14 @@
 * DESCRIPTION: Scheme objects
 * COPYRIGHT  : (C) 2003  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
-#include "guile.hpp"
+#include "config.h"
 #include "Glue/glue.hpp"
+#include "guile.hpp"
 #include "Scheme/evaluate.hpp"
 #include "Scheme/object.hpp"
 #include "list.hpp"
@@ -52,12 +52,12 @@ object_rep::lookup () {
 * Routines on objects
 ******************************************************************************/
 
-ostream&
-operator << (ostream& out, object obj) {
+tm_ostream&
+operator << (tm_ostream& out, object obj) {
   out.flush ();
   if (out == cout) call ("write", obj);
   else if (out == cerr) call ("write-err", obj);
-  else fatal_error ("Not yet implemented", "object::operator <<", "object.cpp");
+  else FAILED ("not yet implemented");
   call ("force-output");
   return out;
 }
@@ -73,6 +73,11 @@ operator != (object obj1, object obj2) {
   return !(obj1 == obj2);
 }
 
+int
+hash (object obj) {
+  return as_int (call ("hash", obj, object (1234567)));
+}
+
 /******************************************************************************
 * Utilities
 ******************************************************************************/
@@ -124,17 +129,17 @@ bool is_url (object obj) { return scm_is_url (obj->lookup()); }
 * Basic conversions
 ******************************************************************************/
 
-object::object (): rep (new object_rep (SCM_NULL)) {}
-object::object (bool b): rep (new object_rep (bool_to_scm (b))) {}
-object::object (int i): rep (new object_rep (int_to_scm (i))) {}
+object::object (): rep (tm_new<object_rep> (SCM_NULL)) {}
+object::object (bool b): rep (tm_new<object_rep> (bool_to_scm (b))) {}
+object::object (int i): rep (tm_new<object_rep> (int_to_scm (i))) {}
 object::object (const char* s):
-  rep (new object_rep (string_to_scm (string (s)))) {}
-object::object (string s): rep (new object_rep (string_to_scm (s))) {}
-object::object (tree t): rep (new object_rep (tree_to_scm (t))) {}
-object::object (list<string> l): rep (new object_rep(list_string_to_scm(l))) {}
-object::object (list<tree> l): rep (new object_rep (list_tree_to_scm (l))) {}
-object::object (path p): rep (new object_rep (path_to_scm (p))) {}
-object::object (url u): rep (new object_rep (url_to_scm (u))) {}
+  rep (tm_new<object_rep> (string_to_scm (string (s)))) {}
+object::object (string s): rep (tm_new<object_rep> (string_to_scm (s))) {}
+object::object (tree t): rep (tm_new<object_rep> (tree_to_scm (t))) {}
+object::object (list<string> l): rep (tm_new<object_rep> (list_string_to_scm(l))) {}
+object::object (list<tree> l): rep (tm_new<object_rep> (list_tree_to_scm (l))) {}
+object::object (path p): rep (tm_new<object_rep> (path_to_scm (p))) {}
+object::object (url u): rep (tm_new<object_rep> (url_to_scm (u))) {}
 
 bool
 as_bool (object obj) {
@@ -265,24 +270,24 @@ class object_command_rep: public command_rep {
 public:
   object_command_rep (object obj2): obj (obj2) {}
   void apply () { (void) call_scheme (obj->lookup ()); }
-  ostream& print (ostream& out) { return out << obj; }
+  tm_ostream& print (tm_ostream& out) { return out << obj; }
 };
 
 command
 as_command (object obj) {
-  return new object_command_rep (obj);
+  return tm_new<object_command_rep> (obj);
 }
 
 class object_promise_widget_rep: public promise_rep<widget> {
   object obj;
 public:
   object_promise_widget_rep (object obj2): obj (obj2) {}
-  ostream& print (ostream& out) { return out << obj; }
+  tm_ostream& print (tm_ostream& out) { return out << obj; }
   widget eval () {
     SCM result= call_scheme (obj->lookup ());
     if (scm_is_widget (result)) return scm_to_widget (result);
     else {
-      fatal_error ("Widget expected", "eval_as_widget", "object.cpp");
+      FAILED ("widget expected");
       return glue_widget ();
     }
   }
@@ -290,7 +295,7 @@ public:
 
 promise<widget>
 as_promise_widget (object obj) {
-  return new object_promise_widget_rep (obj);
+  return tm_new<object_promise_widget_rep> (obj);
 }
 
 /******************************************************************************
@@ -329,6 +334,9 @@ object call (const char* fun, object a1, object a2) {
 object call (const char* fun, object a1, object a2, object a3) {
   return object (call_scheme (eval_scheme(fun), a1->lookup(),
 			      a2->lookup(), a3->lookup())); }
+object call (const char* fun, object a1, object a2, object a3, object a4) {
+  return object (call_scheme (eval_scheme(fun), a1->lookup(),
+			      a2->lookup(), a3->lookup(), a4->lookup())); }
 object call (const char* fun, array<object> a) {
   return object (call_scheme (eval_scheme(fun), array_lookup(a))); }
 
@@ -341,6 +349,9 @@ object call (string fun, object a1, object a2) {
 object call (string fun, object a1, object a2, object a3) {
   return object (call_scheme (eval_scheme(fun), a1->lookup(),
 			      a2->lookup(), a3->lookup())); }
+object call (string fun, object a1, object a2, object a3, object a4) {
+  return object (call_scheme (eval_scheme(fun), a1->lookup(),
+			      a2->lookup(), a3->lookup(), a4->lookup())); }
 object call (string fun, array<object> a) {
   return object (call_scheme (eval_scheme(fun), array_lookup(a))); }
 
@@ -353,6 +364,9 @@ object call (object fun, object a1, object a2) {
 object call (object fun, object a1, object a2, object a3) {
   return object (call_scheme (fun->lookup(), a1->lookup(),
 			      a2->lookup(), a3->lookup())); }
+object call (object fun, object a1, object a2, object a3, object a4) {
+  return object (call_scheme (fun->lookup(), a1->lookup(),
+			      a2->lookup(), a3->lookup(), a4->lookup())); }
 object call (object fun, array<object> a) {
   return object (call_scheme (fun->lookup(), array_lookup(a))); }
 
@@ -360,31 +374,49 @@ object call (object fun, array<object> a) {
 * Delayed evaluation
 ******************************************************************************/
 
+#ifndef QTTEXMACS
 static array<object> delayed_queue;
-
-void
-eval_delayed (string expr) {
-  delayed_queue << scheme_cmd (expr);
-}
-
-void
-eval_delayed (object expr) {
-  delayed_queue << scheme_cmd (expr);
-}
+static array<time_t> start_queue;
 
 void
 exec_delayed (object cmd) {
   delayed_queue << cmd;
+  start_queue << (((time_t) texmacs_time ()) - 1000000000);
+}
+
+void
+exec_delayed_pause (object cmd) {
+  delayed_queue << cmd;
+  start_queue << ((time_t) texmacs_time ());
 }
 
 void
 exec_pending_commands () {
   array<object> a= delayed_queue;
+  array<time_t> b= start_queue;
   delayed_queue= array<object> (0);
+  start_queue  = array<time_t> (0);
   int i, n= N(a);
   for (i=0; i<n; i++) {
-    object obj= call (a[i]);
-    if (is_bool (obj) && !as_bool (obj))
+    time_t now= (time_t) texmacs_time ();
+    if ((now - b[i]) >= 0) {
+      object obj= call (a[i]);
+      if (is_int (obj) && (now - b[i] < 1000000000)) {
+        //cout << "pause= " << obj << "\n";
+        delayed_queue << a[i];
+        start_queue << (now + as_int (obj));
+      }
+    }
+    else {
       delayed_queue << a[i];
+      start_queue << b[i];
+    }
   }
 }
+
+void
+clear_pending_commands () {
+  delayed_queue= array<object> (0);
+  start_queue  = array<time_t> (0);
+}
+#endif // QTTEXMACS
