@@ -37,10 +37,10 @@ typedef list<int> path;
 extern int observer_count;
 class observer_rep: public abstract_struct {
 public:
-  inline observer_rep () { DEBUG(observer_count++); }
-  inline virtual ~observer_rep () { DEBUG(observer_count--); }
+  inline observer_rep () { TM_DEBUG(observer_count++); }
+  inline virtual ~observer_rep () { TM_DEBUG(observer_count--); }
   inline virtual int get_type () { return OBSERVER_UNKNOWN; }
-  inline virtual ostream& print (ostream& out) { return out; }
+  inline virtual tm_ostream& print (tm_ostream& out) { return out; }
 
   // Announcing modifications in subtrees
   virtual void announce             (tree& ref, modification mod);
@@ -89,11 +89,10 @@ public:
 };
 ABSTRACT_NULL_CODE(observer);
 
-ostream& operator << (ostream& out, observer o);
+tm_ostream& operator << (tm_ostream& out, observer o);
 
 class editor_rep;
-class tm_buffer_rep;
-typedef tm_buffer_rep* tm_buffer;
+class archiver_rep;
 
 extern observer nil_observer;
 observer ip_observer (path ip);
@@ -101,7 +100,7 @@ observer list_observer (observer o1, observer o2);
 observer tree_pointer (tree t, bool flag= false);
 observer tree_position (tree t, int index);
 observer edit_observer (editor_rep* ed);
-observer undo_observer (tm_buffer buf);
+observer undo_observer (archiver_rep* arch);
 
 /******************************************************************************
 * Modification routines for trees and other observer-related facilities
