@@ -4,10 +4,9 @@
 * DESCRIPTION: generating bibliographies using BiBTeX
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Bibtex/bibtex.hpp"
@@ -52,7 +51,7 @@ search_bib (tree t) {
 }
 
 tree
-bibtex_run (string style, string dir, string fname, tree bib_t) {
+bibtex_run (string bib, string style, string dir, string fname, tree bib_t) {
   int i;
   string bib_s= "\\bibstyle{" * style * "}\n";
   for (i=0; i<arity(bib_t); i++)
@@ -67,7 +66,7 @@ bibtex_run (string style, string dir, string fname, tree bib_t) {
 #ifdef OS_WIN32
   char *directory = as_charp(dir);
   RunBibtex(directory, "$TEXMACS_HOME_PATH/system/bib", "temp");
-  delete [] directory;
+  tm_delete_array (directory);
 #else
   string cmdln= "cd $TEXMACS_HOME_PATH/system/bib; ";
   cmdln << "BIBINPUTS=" << dir << ":$BIBINPUTS "
@@ -98,7 +97,8 @@ bibtex_run (string style, string dir, string fname, tree bib_t) {
 	  item= compound ("bibitem*", as_string (count++), item[0]);
 	t[i][0]= item;
 	tree v (CONCAT, compound ("bibitem*", item[0]));
-	if (is_atomic (item[1])) v << tree (LABEL, "bib-" * item[1]->label);
+	if (is_atomic (item[1]))
+	  v << tree (LABEL, bib * "-" * item[1]->label);
 	if (N(t[i])>1) {
 	  v << remove_start_space (t[i][1]);
 	  v << A (t[i] (2, N(t[i])));
