@@ -4,10 +4,9 @@
 * DESCRIPTION: generating bibliographies using BiBTeX
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef BIBTEX_H
@@ -15,6 +14,7 @@
 #include "tree.hpp"
 
 void set_bibtex_command (string cmd);
-tree bibtex_run (string style, string dir, string fname, tree bib_t);
+tree bibtex_run (string bib, string style, string dir, string fname,
+		 tree bib_t);
 
 #endif // BIBTEX_H
