@@ -4,26 +4,22 @@
 * DESCRIPTION: Main TeXmacs view
 * COPYRIGHT  : (C) 2007  Massimiliano Gubinelli
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "mac_cocoa.h"
 #include "aqua_simple_widget.h"
 
-@interface TMSimpleView : NSView {
+@interface TMView : NSView  <NSTextInput>
+{
 	simple_widget_rep *wid;
+  NSString *workingText;
+  BOOL processingCompose;
+  NSMutableArray *delayed_rects;
 }
 - (void) setWidget:(widget_rep*) w;
 - (widget_rep*) widget;
-@end
-
-@interface TMView : TMSimpleView  <NSTextInput>
-{
-  NSString *workingText;
-  BOOL processingCompose;
-}
 - (void) deleteWorkingText;
 @end
