@@ -123,13 +123,13 @@ public:
 
 - (NSImage*) image
 {
-	NSImage *img = [super image];
-	if ((!img)&&(wid))
-	{
-		SI width, height;
-		wid->handle_get_size_hint (width,height);
-		NSSize s = NSMakeSize(width/PIXEL,height/PIXEL);
-   
+  NSImage *img = [super image];
+  if ((!img)&&(wid))
+  {
+    SI width, height;
+    wid->handle_get_size_hint (width,height);
+    NSSize s = NSMakeSize(width/PIXEL,height/PIXEL);
+    
     img = [[[NSImage alloc] initWithSize:s] autorelease];
     [img lockFocus];
     
@@ -138,9 +138,9 @@ public:
     int y1 = s.height;
     int x2 = s.width;
     int y2 = 0;
-
+    
     r -> begin([NSGraphicsContext currentContext]);
-
+    
     r -> encode (x1,y1);
     r -> encode (x2,y2);
     r -> set_clipping (x1,y1,x2,y2);
@@ -150,8 +150,8 @@ public:
     //[img setFlipped:YES];
     [super setImage:img];			
     [self setWidget:NULL];
-	}
-	return img;
+  }
+  return img;
 }
 @end
 
@@ -323,15 +323,17 @@ widget menu_separator (bool vertical) { return tm_new <aqua_menu_rep> ([NSMenuIt
 widget menu_group (string name, string lan) 
 // a menu group; the name should be greyed and centered
 {
-	NSMenuItem* mi = [[alloc_menuitem() initWithTitle:to_nsstring(name) action:NULL keyEquivalent:@""] autorelease];
+	NSMenuItem* mi = [[alloc_menuitem() initWithTitle:to_nsstring_utf8(name) action:NULL keyEquivalent:@""] autorelease];
 
 	//	NSAttributedString *str = [mi attributedTitle];
 	NSMutableParagraphStyle *style = [[[NSParagraphStyle defaultParagraphStyle] mutableCopy] autorelease];
 //	NSMutableParagraphStyle *style = [(NSParagraphStyle*)[str attribute:NSParagraphStyleAttributeName atIndex:0 effectiveRange:NULL] mutableCopy];
-	[style setAlignment:NSCenterTextAlignment];
-	[mi setAttributedTitle:[[[NSAttributedString alloc] initWithString:[mi title]
-																													attributes:[NSDictionary dictionaryWithObjectsAndKeys:style, NSParagraphStyleAttributeName,
-																																				 nil]] autorelease]];
+	[style setAlignment: NSCenterTextAlignment];
+	[mi setAttributedTitle:[[[NSAttributedString alloc] 
+                               initWithString: [mi title]
+                                   attributes: [NSDictionary 
+                                      dictionaryWithObjectsAndKeys:style, NSParagraphStyleAttributeName, nil]]
+                                autorelease]];
 	return tm_new <aqua_menu_rep> (mi);
 }
 
@@ -358,7 +360,7 @@ widget pullright_button (widget w, promise<widget> pw)
 
 TMMenuItem * aqua_text_widget_rep::as_menuitem()
 {
-  return [[[TMMenuItem alloc] initWithTitle:to_nsstring(str) action:NULL keyEquivalent:@""] autorelease];
+  return [[[TMMenuItem alloc] initWithTitle:to_nsstring_utf8(str) action:NULL keyEquivalent:@""] autorelease];
 }
 
 TMMenuItem * aqua_image_widget_rep::as_menuitem()
@@ -422,7 +424,8 @@ widget balloon_widget (widget w, widget help)
 widget text_widget (string s, color col, bool tsp, string lan) 
 // a text widget with a given color, transparency and language
 {
-  return tm_new <aqua_text_widget_rep> (s,col,tsp,lan);
+  string t= aqua_translate (s);
+  return tm_new <aqua_text_widget_rep> (t,col,tsp,lan);
 }
 widget xpm_widget (url file_name)// { return widget(); }
 // a widget with an X pixmap icon
