@@ -4,10 +4,9 @@
 * DESCRIPTION: True Type fonts (using FreeType II)
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "font.hpp"
@@ -146,7 +145,7 @@ unicode_font_rep::get_extents (string s, metric& ex) {
 
 void
 unicode_font_rep::get_xpositions (string s, SI* xpos) {
-  register int i= 0, n= N(s);
+  int i= 0, n= N(s);
   if (n == 0) return;
   
   register SI x= 0;
@@ -188,7 +187,7 @@ font
 unicode_font (string family, int size, int dpi) {
   string name= "unicode:" * family * as_string (size) * "@" * as_string(dpi);
   return make (font, name,
-    new unicode_font_rep (name, family, size, dpi));
+    tm_new<unicode_font_rep> (name, family, size, dpi));
 }
 
 #else
@@ -197,7 +196,7 @@ font
 unicode_font (string family, int size, int dpi) {
   string name= "unicode:" * family * as_string (size) * "@" * as_string(dpi);
   cerr << "\n\nFont name= " << name << "\n";
-  fatal_error ("True type support was disabled", "unicode_font");
+  FAILED ("true type support was disabled");
   return font ();
 }
 
