@@ -4,10 +4,9 @@
 * DESCRIPTION: interface with the ispell spell checker
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Ispell/ispell.hpp"
@@ -59,13 +58,19 @@ ispeller_rep::start () {
   }
   if (ln->alive) return "ok";
   string message= ln->start ();
-  if (starts (message, "Error: ")) return message;
+  if (DEBUG_IO) cout << "Ispell] Received " << message << "\n";
+  if (starts (message, "Error: ")) {
+    if (ln->alive) ln->stop ();
+    return message;
+  }
   message= retrieve ();
+  if (DEBUG_IO) cout << "Ispell] Received " << message << "\n";
 #ifdef OS_WIN32
   if (search_forwards (message, 0, "@(#)")) return "ok";
 #else
   if (starts (message, "@(#)")) return "ok";
 #endif
+  if (ln->alive) ln->stop ();
   return "Error: no dictionary for#" * lan;
 }
 
@@ -82,7 +87,7 @@ ispeller_rep::retrieve () {
       if (extra == "") return "Error: ispell does not respond";
       ret << extra;
     }
-  return ispell_decode(lan,ret);
+  return ispell_decode (lan, ret);
 }
 
 void
@@ -229,6 +234,7 @@ ispell_eval (string lan, string s) {
     sc->send (s);
     return sc->retrieve ();
   }
+  return "";
 }
 
 /******************************************************************************
@@ -237,13 +243,15 @@ ispell_eval (string lan, string s) {
 
 string
 ispell_start (string lan) {
+  if (DEBUG_IO) cout << "Ispell] Start " << lan << "\n";
   ispeller sc= ispeller (lan);
-  if (is_nil (sc)) sc= new ispeller_rep (lan);
+  if (is_nil (sc)) sc= tm_new<ispeller_rep> (lan);
   return sc->start ();
 }
 
 tree
 ispell_check (string lan, string s) {
+  if (DEBUG_IO) cout << "Ispell] Check " << s << "\n";
   ispeller sc= ispeller (lan);
   if (is_nil (sc) || (!sc->ln->alive)) {
     string message= ispell_start (lan);
@@ -256,15 +264,18 @@ ispell_check (string lan, string s) {
 
 void
 ispell_accept (string lan, string s) {
+  if (DEBUG_IO) cout << "Ispell] Accept " << s << "\n";
   ispell_send (lan, "@" * s);
 }
 
 void
 ispell_insert (string lan, string s) {
+  if (DEBUG_IO) cout << "Ispell] Insert " << s << "\n";
   ispell_send (lan, "*" * s);
 }
 
 void
 ispell_done (string lan) {
+  if (DEBUG_IO) cout << "Ispell] End " << lan << "\n";
   ispell_send (lan, "#");
 }
