@@ -4,10 +4,9 @@
 * DESCRIPTION: load TeX font metric file
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "load_tex.hpp"
@@ -39,16 +38,16 @@ tex_font_metric_rep::tex_font_metric_rep (string name):
 }
 
 tex_font_metric_rep::~tex_font_metric_rep () {
-  if (header != NULL) delete[] header;
-  if (char_info != NULL) delete[] char_info;
-  if (width != NULL) delete[] width;
-  if (height != NULL) delete[] height;
-  if (depth != NULL) delete[] depth;
-  if (italic != NULL) delete[] italic;
-  if (lig_kern != NULL) delete[] lig_kern;
-  if (kern != NULL) delete[] kern;
-  if (exten != NULL) delete[] exten;
-  if (param != NULL) delete[] param;
+  if (header != NULL) tm_delete_array (header);
+  if (char_info != NULL) tm_delete_array (char_info);
+  if (width != NULL) tm_delete_array (width);
+  if (height != NULL) tm_delete_array (height);
+  if (depth != NULL) tm_delete_array (depth);
+  if (italic != NULL) tm_delete_array (italic);
+  if (lig_kern != NULL) tm_delete_array (lig_kern);
+  if (kern != NULL) tm_delete_array (kern);
+  if (exten != NULL) tm_delete_array (exten);
+  if (param != NULL) tm_delete_array (param);
 }
 
 /******************************************************************************
@@ -146,18 +145,27 @@ tex_font_metric_rep::execute (int* s, int n, int* buf, int* ker, int& m) {
       while (true) {
 	register int instr= lig_kern [pc];
 
-	if (byte0 (instr) >= 128) { // halt
-	  // cout << "  Halt\n";
-	  ker [bp]  = 0;
-	  buf [bp++]= stack[sp--];
-	  break;
-	}
+	//if (byte0 (instr) >= 128) { // halt
+	//  // cout << "  Halt\n";
+	//  ker [bp]  = 0;
+	//  buf [bp++]= stack[sp--];
+	//  break;
+	//}
 
 	if (byte1 (instr) != next_char) { // continue
 	  // cout << "  " << (char) byte1 (instr) << " != " << (char) next_char
 	  //      << " => pc := pc + " << (byte0 (instr)+1) << "\n";
-	  pc += byte0 (instr)+1;
-	  continue;
+	  int skip_byte = byte0(instr);
+  	  if (skip_byte >= 128) { // current instruction is the final instruction
+	    // cout << "  Halt\n";
+	    ker [bp]  = 0;
+	    buf [bp++]= stack[sp--];
+	    break;
+	  }
+	  else {
+	    pc += skip_byte+1;
+	    continue;
+	  }
 	}
 
 	// cout << "  " << (char) byte1 (instr) << " == "
@@ -200,9 +208,7 @@ tex_font_metric_rep::execute (int* s, int n, int* buf, int* ker, int& m) {
       cerr << "\nString is ";
       for (i=0; i<n; i++) cerr << (char) s[i];
       cerr << "\n";
-      fatal_error ("String too complex for ligature kerning",
-		   "tex_font_metric_rep::execute",
-		   "load-tfm.cpp");
+      FAILED ("string too complex for ligature kerning");
     }
   }
   
@@ -277,9 +283,7 @@ tex_font_metric_rep::get_xpositions (int* s, int n, double unit, SI* xpos) {
       cerr << "\nString is ";
       for (i=0; i<n; i++) cerr << (char) s[i];
       cerr << "\n";
-      fatal_error ("String too complex for ligature kerning",
-		   "tex_font_metric_rep::get_xpositions",
-		   "load-tfm.cpp");
+      FAILED ("string too complex for ligature kerning");
     }
   }
   STACK_DELETE_ARRAY (stack);
@@ -368,7 +372,7 @@ print (tex_font_metric tfm) {
 tex_font_metric
 load_tfm (url file_name, string family, int size) {
   tex_font_metric tfm=
-    new tex_font_metric_rep (family * as_string (size) * ".tfm");
+    tm_new<tex_font_metric_rep> (family * as_string (size) * ".tfm");
 
   int i= 0;
   string s;
@@ -392,7 +396,7 @@ load_tfm (url file_name, string family, int size) {
       (tfm->lh + (tfm->ec + 1 - tfm->bc) +
        tfm->nw + tfm->nh + tfm->nd + tfm->ni +
        tfm->nl + tfm->nk + tfm->ne + tfm->np))
-    fatal_error ("invalid tfm file", "load_tfm", "load-tfm.cpp");
+    FAILED ("invalid tfm file");
   
   parse (s, i, tfm->header, tfm->lh);
   parse (s, i, tfm->char_info, tfm->ec+1- tfm->bc);
