@@ -18,27 +18,30 @@
 #include <QAction>
 #include <QMenu>
 
+#include "qt_gui.hpp"
+
 class QTMCommand: public QObject {
   Q_OBJECT
   command cmd;
-	
+        
 public:
   inline QTMCommand (command _cmd):
     cmd (_cmd) {  }
 
 public slots:
-  inline void apply() {
-    if (!is_nil(cmd)) cmd->apply(); }
+  void apply() {
+//    if (!is_nil(cmd)) { cmd->apply();  needs_update(); }
+    if (!is_nil(cmd)) { the_gui->process_command(cmd); }
+  }
 };
 
 class QTMLazyMenu: public QMenu {
   Q_OBJECT
   promise<widget> pm;
-  bool forced;
 
 public:
   inline QTMLazyMenu (promise<widget> _pm):
-    pm (_pm), forced (false) {
+    pm (_pm) {
       QObject::connect (this, SIGNAL (aboutToShow ()), this, SLOT (force ()));
     }
 
