@@ -4,10 +4,9 @@
 * DESCRIPTION: A file_chooser widget with horizontal and vertical scrollbars.
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Widkit/basic_widget.hpp"
@@ -51,7 +50,7 @@ class file_chooser_command_rep: public command_rep {
 public:
   file_chooser_command_rep (wk_widget w, int t): fch(w.rep), type(t) {}
   void apply ();
-  ostream& print (ostream& out) {
+  tm_ostream& print (tm_ostream& out) {
     return out << "File chooser command (" << type << ")"; }
 };
 
@@ -128,7 +127,7 @@ file_chooser_command_rep::apply () {
 
 command
 file_chooser_command (wk_widget fch, int type) {
-  return new file_chooser_command_rep (fch, type);
+  return tm_new<file_chooser_command_rep> (fch, type);
 }
 
 /******************************************************************************
@@ -212,22 +211,23 @@ file_list_widget_rep::handle_get_size (get_size_event ev) {
 
 void
 file_list_widget_rep::handle_repaint (repaint_event ev) { (void) ev;
+  renderer ren= win->get_renderer ();
   int i; 
   metric ex;
-  win->set_background (white);
-  win->clear (0, -h, w, 0);
+  ren->set_background (white);
+  ren->clear (0, -h, w, 0);
   font fn= get_default_font ();
-  win->set_shrinking_factor (3);
+  ren->set_shrinking_factor (3);
   SI y= 0;
   for (i=0; i<N(names); i++)
     if (lids[i]) {
-      win->set_color (black);
-      if (hilight == i) win->set_color (red);
+      ren->set_color (black);
+      if (hilight == i) ren->set_color (red);
       fn->var_get_extents (names[i], ex);
-      fn ->draw (win, names[i], 9*PIXEL, y-fn->y2-6*PIXEL);
+      fn ->draw (ren, names[i], 9*PIXEL, y-fn->y2-6*PIXEL);
       y += fn->y1- fn->y2- 12*PIXEL;
     }
-  win->set_shrinking_factor (1);
+  ren->set_shrinking_factor (1);
 }
 
 void
@@ -322,9 +322,10 @@ image_widget_rep::handle_get_size (get_size_event ev) {
 
 void
 image_widget_rep::handle_repaint (repaint_event ev) { (void) ev;
-  win->set_background (white);
-  win->clear (0, 0, w, h);
-  layout_dark_outline (win, 0, 0, w, h);
+  renderer ren= win->get_renderer ();
+  ren->set_background (white);
+  ren->clear (0, 0, w, h);
+  layout_dark_outline (ren, 0, 0, w, h);
   if (file_name != "") {
     SI iw, ih;
     image_size (url_system (file_name), iw, ih);
@@ -336,7 +337,7 @@ image_widget_rep::handle_repaint (repaint_event ev) { (void) ev;
       else ww= (hh * iw) / ih;
     }
 
-    win->image (url_system (file_name),
+    ren->image (url_system (file_name),
 		ww, hh, PIXEL, PIXEL, 0.0, 0.0, 1.0, 1.0);
   }
 }
@@ -432,12 +433,12 @@ file_chooser_widget_rep::file_chooser_widget_rep (
   array<string> cn2 (cw2n);
   cw2[0]= glue_wk_widget (false, true, sep);
   cw2[1]=
-    canvas_widget (wk_widget (new file_list_widget_rep (this, suffix, true)));
+    canvas_widget (wk_widget (tm_new<file_list_widget_rep> (this, suffix, true)));
   cn2[1]= "directories";
   cw2[2]= glue_wk_widget (false, true, sep);
   if (type != "directory") {
     cw2[3]=
-      canvas_widget (wk_widget (new file_list_widget_rep (this,suffix,false)));
+      canvas_widget (wk_widget (tm_new<file_list_widget_rep> (this,suffix,false)));
     cn2[3]= "files";
     cw2[4]= glue_wk_widget (false, true, sep-PIXEL);
   }
@@ -451,7 +452,7 @@ file_chooser_widget_rep::file_chooser_widget_rep (
       driveString[0] = x;
       drive_menu << emit_insert (driveString,
 	command_button (text_wk_widget (driveString),
-			new drive_menu_command_rep (this, driveString)));
+			tm_new<drive_menu_command_rep> (this, driveString)));
     }
   array<wk_widget> drw (2);
   drw[0] = pullright_button (text_wk_widget ("Drive"), drive_menu);
@@ -485,7 +486,7 @@ file_chooser_widget_rep::file_chooser_widget_rep (
   cw3[5]= button_widget ("Ok", BUTTON_OK);
   cw3[6]= glue_wk_widget (false, false, sep);
   cw3[7]= button_widget ("Cancel", BUTTON_CANCEL);
-#ifdef OS_DARWIN
+#ifdef OS_MACOS
   cw3[8]= glue_wk_widget (false, false, sep + 14*PIXEL);
 #else
   cw3[8]= glue_wk_widget (false, false, sep);
@@ -545,7 +546,7 @@ file_chooser_widget_rep::file_chooser_widget_rep (
     cw4[1] = vertical_list (imw, ims);
     cn4[1] = "parameters";
     cw4[2] = glue_wk_widget (false, false, sep);
-    cw4[3] = new image_widget_rep ();
+    cw4[3] = tm_new<image_widget_rep> ();
     cn4[3] = "image";
     cw4[4] = glue_wk_widget (false, false, sep);
 
@@ -711,5 +712,5 @@ file_chooser_widget_rep::handle_destroy (destroy_event ev) {
 
 wk_widget
 file_chooser_wk_widget (command cmd, string type, string magn) {
-  return new file_chooser_widget_rep (cmd, type, magn);
+  return tm_new<file_chooser_widget_rep> (cmd, type, magn);
 }
