@@ -65,6 +65,8 @@
 #include "file.hpp"
 #include "analyze.hpp"
 
+#include <ctype.h>
+
 #if defined(OS_WIN32)  || defined(__MINGW32__)
 #define WINPATHS
 #endif
@@ -479,8 +481,8 @@ as_string (url u, int type) {
   return "";
 }
 
-ostream&
-operator << (ostream& out, url u) {
+tm_ostream&
+operator << (tm_ostream& out, url u) {
   return out << as_string (u, URL_SYSTEM);
 }
 
@@ -701,6 +703,7 @@ complete (url base, url sub, url u, string filter, bool flag) {
 
 url
 complete (url base, url u, string filter, bool flag) {
+ // cout << "complete " << base << " |||| " << u << LF;
   if (is_none (base)) return base;
   if (is_none (u)) return u;
   if ((!is_root (base)) && (!is_rooted_name (base))) {
@@ -810,7 +813,11 @@ exists (url u) {
 
 bool
 exists_in_path (url u) {
+#if defined (OS_WIN32) || defined (__MINGW__) || defined (__MINGW32__)
+  return !is_none (resolve_in_path (url (as_string (u) * ".exe")));
+#else
   return !is_none (resolve_in_path (u));
+#endif
 }
 
 bool
@@ -866,7 +873,7 @@ string
 materialize (url u, string filter) {
   // Combines resolve and concretize
   url r= resolve (u, filter);
-  if (!(is_rooted (u) || is_here (u) || is_parent (u))) {
+  if (!(is_rooted (r) || is_here (r) || is_parent (r))) {
     cerr << "\nu= " << u << LF;
     FAILED ("url could not be resolved");
   }
