@@ -4,10 +4,9 @@
 * DESCRIPTION: image file handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "file.hpp"
@@ -17,12 +16,24 @@
 #include "analyze.hpp"
 #include "hashmap.hpp"
 #include "scheme.hpp"
-#include "../Plugins/Imlib2/imlib2.hpp"
+#include "Imlib2/imlib2.hpp"
+
+#ifdef MACOSX_EXTENSIONS
+#include "MacOS/mac_images.h"
+#endif
+
+#ifdef QTTEXMACS
+#include "Qt/qt_utilities.hpp"
+#endif
 
 #ifdef OS_WIN32
 #include <x11/xlib.h>
 #endif
 
+#ifdef USE_GS
+#include "Ghostscript/gs_utilities.hpp"
+#endif
+
 hashmap<tree,string> ps_bbox ("");
 
 /******************************************************************************
@@ -64,7 +75,10 @@ xpm_size (url u, int& w, int& h) {
   ok= read_int (s, i, w);
   skip_spaces (s, i);
   ok= read_int (s, i, h) && ok;
-  if (!ok) fatal_error ("Invalid xpm (" * file_name * ")", "xpm_size");
+  if (!ok) {
+    cerr << "File name= " << file_name << "\n";
+    FAILED ("invalid xpm");
+  }
 }
 
 array<string>
@@ -80,8 +94,7 @@ xpm_colors (tree t) {
   ok= read_int (s, i, c) && ok;
   skip_spaces (s, i);
   ok= read_int (s, i, b) && ok;
-  if ((!ok) || (N(t)<(c+1)) || (c<=0))
-    fatal_error ("Invalid xpm tree", "x_drawable_rep::xpm_colors");
+  ASSERT (ok && N(t)>c && c>0, "invalid xpm tree");
 
   for (k=0; k<c; k++) {
     string s   = as_string (t[k+1]);
@@ -120,8 +133,7 @@ xpm_hotspot (tree t) {
   ok= read_int (s, i, c) && ok;
   skip_spaces (s, i);
   ok= read_int (s, i, b) && ok;
-  if ((!ok) || (N(t)<(c+1)) || (c<=0))
-    fatal_error ("Invalid xpm tree", "x_drawable_rep::xpm_hotspot");
+  ASSERT (ok && N(t)>c && c>0, "invalid xpm tree");
 
   skip_spaces (s, i);
   ok= read_int (s, i, x) && ok;
@@ -157,7 +169,7 @@ ps_load (url image) {
     char *data;
     char *path= as_charp (as_string (name));
     data= XLoadImageAsPS (path);
-    delete[] path;
+    tm_delete_array (path);
     if (!data) s= "";
     else {
       s= string (data);
@@ -214,12 +226,101 @@ ps_bounding_box (url image, int& x1, int& y1, int& x2, int& y2) {
 
 void
 image_size (url image, int& w, int& h) {
-  if (imlib2_supports (image))
-    imlib2_image_size (image, w, h);
-  else {
-    int x1, y1, x2, y2;
-    ps_bounding_box (image, x1, y1, x2, y2);
-    w= x2 - x1;
-    h= y2 - y1;
+#ifdef QTTEXMACS
+  if (qt_supports (image)) {
+    qt_image_size (image, w, h); // default to 72 dpi
+    return;
   }
+#endif
+#ifdef USE_IMLIB2
+  if (imlib2_supports (image)) {
+    imlib2_image_size (image, w, h);
+    return;
+  }
+#endif
+#ifdef USE_GS
+  if (gs_supports (image)) {
+    gs_image_size (image, w, h);
+    return;
+  }
+#endif
+  int x1, y1, x2, y2;
+  ps_bounding_box (image, x1, y1, x2, y2);
+  w= x2 - x1;
+  h= y2 - y1;
 }
+
+/******************************************************************************
+* Converting image formats
+******************************************************************************/
+
+void
+image_to_eps (url image, url eps, int w_pt, int h_pt, int dpi) {
+/*  if ((suffix (eps) != "eps") && (suffix (eps) != "ps")) {
+    cerr << "TeXmacs] warning: " << concretize (eps) << " has no .eps or .ps suffix\n";
+  }*/
+#ifdef QTTEXMACS
+  if (qt_supports (image)) {
+    qt_image_to_eps (image, eps, w_pt, h_pt, dpi);
+    return;
+  }
+#endif
+#ifdef USE_GS
+  if (gs_supports (image)) {
+    gs_to_eps (image, eps);
+    return;
+  }
+#endif
+  string s= suffix (image);
+  string cmd= "convert";
+  if (s != "pdf" && s != "ps" && s != "eps" && dpi > 0 && w_pt > 0 && h_pt > 0) {
+    int ww= w_pt * dpi / 72;
+    int hh= h_pt * dpi / 72;
+    string sz= eval_system ("identify -format \"%[fx:w] %[fx:h]\"", image);
+    int w_px, h_px, ok= true, pos= 0;
+    ok= read_int (sz, pos, w_px);
+    skip_spaces (sz, pos);  
+    ok= ok && read_int (sz, pos, h_px);
+    if (ok && (ww < w_px || hh < h_px)) {
+      cmd << " -resize " * as_string (ww) * "x" * as_string (hh) * "!";
+    }
+  }
+  system (cmd, image, eps);
+}
+
+string
+image_to_psdoc (url image) {
+  url psfile= url_temp (".eps");
+  image_to_eps (image, psfile);
+  string psdoc;
+  load_string (psfile, psdoc, false);
+  remove (psfile);
+  return psdoc;
+}
+
+void
+image_to_png (url image, url png, int w, int h) {
+/*  if (suffix (png) != "png") {
+    cerr << "TeXmacs] warning: " << concretize (png) << " has no .png suffix\n";
+  }*/
+#ifdef MACOSX_EXTENSIONS
+  mac_image_to_png (image, png);
+#else
+#ifdef QTTEXMACS
+  if (qt_supports (image)) {
+    qt_convert_image (image, png);
+    return;
+  }
+#endif
+#ifdef USE_GS
+  if (gs_supports (image)) {
+    gs_to_png (image, png, w, h);
+    return;
+  }
+#endif
+  string cmd= "convert";
+  if (w > 0 && h > 0) cmd << " -resize " * as_string(w) * "x" * as_string(h) * "!";
+  system (cmd, image, png);
+#endif
+}
+
