@@ -4,10 +4,9 @@
 * DESCRIPTION: image file handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef IMAGE_FILES_H
@@ -21,5 +20,8 @@ array<SI>     xpm_hotspot (tree t);
 void	      ps_bounding_box (url image, int& x1, int& y1, int& x2, int& y2);
 string 	      ps_load (url image);
 void          image_size (url image, int& w, int& h);
+void          image_to_eps (url image, url eps, int w_pt= 0, int h_pt= 0, int dpi= 0);
+string        image_to_psdoc (url image);
+void          image_to_png (url image, url png, int w= 0, int h= 0);
 
 #endif // defined IMAGE_FILES_H
