@@ -4,10 +4,9 @@
 * DESCRIPTION: file handling via the web
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "file.hpp"
@@ -103,8 +102,8 @@ get_from_web (url name) {
   tempFilePath = as_charp(as_string(tmp));
 
   if(!URL_Get(urlPath, tempFilePath)){
-    delete [] urlPath;
-    delete [] tempFilePath;
+    tm_delete_array (urlPath);
+    tm_delete_array (tempFilePath);
     return url_none();
   }
 
@@ -165,7 +164,7 @@ get_from_ramdisc (url u) {
   if (!is_ramdisc (u)) return url_none ();
   url res= get_cache (u);
   if (!is_none (res)) return (res);
-  url tmp= url_temp ();
+  url tmp= url_temp (string (".") * suffix (u));
   save_string (tmp, u[1][2]->t->label);
   return set_cache (u, tmp);
 }
