@@ -12,6 +12,7 @@
 #ifndef TM_LINK_H
 #define TM_LINK_H
 #include "tree.hpp"
+#include "command.hpp"
 
 #define CONNECTION_DEAD    0
 #define CONNECTION_DYING   1
@@ -39,6 +40,8 @@ struct tm_link_rep: abstract_struct {
   bool   alive;   // link is alive
   string secret;  // empty string or secret key for encrypted connections
 
+  command feed_cmd; // called when async data available
+  
 public:
   inline tm_link_rep () {}
   inline virtual ~tm_link_rep () {}
@@ -57,6 +60,8 @@ public:
   void secure_server (string cmd);
   void secure_client ();
 
+  void set_command (command _cmd) { feed_cmd = _cmd; }
+  
   friend class tm_link;
 };
 
@@ -77,4 +82,9 @@ tm_link make_socket_link (string h, int p, int t= SOCKET_DEFAULT, int fd= -1);
 tm_link make_socket_server (int port);
 tm_link find_socket_link (int fd);
 
+void close_all_pipes ();
+void close_all_sockets ();
+void close_all_servers ();
+int  number_of_servers ();
+
 #endif // TM_LINK_H
