@@ -13,7 +13,13 @@
 #include "file.hpp"
 #include "tree.hpp"
 #ifdef OS_WIN32
-#include <sys/misc.h>
+#  include <sys/misc.h>
+#endif
+
+#if defined (QTTEXMACS) && (defined (__MINGW__) || defined (__MINGW32__))
+#  include "Qt/qt_sys_utils.hpp"
+#else
+#  include "Unix/unix_sys_utils.hpp"
 #endif
 
 int script_status = 1;
@@ -22,40 +28,39 @@ int script_status = 1;
 * System functions
 ******************************************************************************/
 
+static int
+system (string s, string& result) {
+#if defined (QTTEXMACS) && (defined (__MINGW__) || defined (__MINGW32__))
+  int r= qt_system (s, result);
+#else
+  int r= unix_system (s, result);
+#endif  
+  return r;
+}
+
 int
 system (string s) {
-#if defined(__MINGW__) || defined(__MINGW32__)
-  if (starts (s, "convert ")) return 1;
-#endif
-  // cout << "System: " << s << "\n";
-  char* _s= as_charp (s);
-#ifdef OS_WIN32
-  int r= _system (_s);
+  if (DEBUG_STD) cerr << "TeXmacs] System: " << s << "\n";
+  if (DEBUG_VERBOSE) {
+    string result;
+    int r= system (s, result);
+    cerr << result;
+    return r;
+  }
+  else {
+#if defined (QTTEXMACS) && (defined (__MINGW__) || defined (__MINGW32__))
+    // if (starts (s, "convert ")) return 1;
+    return qt_system (s);
 #else
-  int r= system (_s);
+    return unix_system (s);
 #endif
-  tm_delete_array (_s);
-  return r;
+  }
 }
 
 string
 eval_system (string s) {
-  url temp= url_temp ();
-  string temp_s= escape_sh (concretize (temp));
-#ifdef OS_WIN32
-  system (s * " > \"" * temp_s * "\"");
-#else
-  system (s * " > " * temp_s);
-#endif
   string result;
-  bool flag= load_string (temp, result, false);
-  remove (temp);
-  if (flag) {
-#ifdef OS_WIN32
-    cerr << "TeXmacs] failed: " << s * " > " * temp_s << "\n";
-#endif
-    return "";
-  }
+  (void) system (s, result);
   return result;
 }
 
@@ -86,9 +91,12 @@ set_env (string var, string with) {
   char* _var = as_charp (var);
   char* _with= as_charp (with);
   setenv (_var, _with, 1);
+  tm_delete_array(_var);
+  tm_delete_array(_with);
 #else
   char* _varw= as_charp (var * "=" * with);
   (void) putenv (_varw);
+  // do not delete _varw !!!
+  // -> known memory leak, but solution more complex than it is worth
 #endif
-  // do not delete _var and _with !!!
 }
