@@ -4,26 +4,21 @@
 * DESCRIPTION: Buffer management for TeXmacs server
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "tm_data.hpp"
 #include "convert.hpp"
 #include "file.hpp"
 #include "web_files.hpp"
-#include "socket_server.hpp"
+#include "tm_link.hpp"
 #include "message.hpp"
 #include "dictionary.hpp"
-#ifdef EXPERIMENTAL
-#include "../../Style/Memorizer/clean_copy.hpp"
-#endif
 
 url tm_init_buffer_file= url_none ();
 url my_init_buffer_file= url_none ();
-int max_undo_depth= 100; // should actually be part of tm_data_rep
 
 /******************************************************************************
 * Constructor and destructor
@@ -86,9 +81,10 @@ tm_data_rep::new_menu_name (url u) {
 static void
 menu_append_buffer (string& s, tm_buffer buf) {
   if (buf->in_menu) {
-    s << " (\"" << buf->abbr;
-    if (buf->needs_to_be_saved ()) s << " *"; 
-    s << "\" (switch-to-buffer \"" * as_string (buf->name) * "\"))";
+    string name= copy (buf->abbr);
+    if (buf->needs_to_be_saved ()) name << " *"; 
+    s << " (" << scm_quote (name);
+    s << " (switch-to-buffer " * scm_quote (as_string (buf->name)) * "))";
   }
 }
 
@@ -165,7 +161,7 @@ tm_buffer
 tm_data_rep::new_buffer (url name) {
   int nr= find_buffer (name);
   if (nr != -1) return bufs[nr];
-  tm_buffer buf= new tm_buffer_rep (name);
+  tm_buffer buf= tm_new<tm_buffer_rep> (name);
   buf->abbr= new_menu_name (name);
   menu_insert_buffer (buf);
   return buf;
@@ -204,7 +200,7 @@ tm_data_rep::revert_buffer (url name, tree doc) {
   if (N(buf->vws)==0) set_document (buf->rp, extract (doc, "body"));
   else for (i=0; i<N(buf->vws); i++) {
     tm_view vw= buf->vws[i];
-    if (i==0) vw->ed->assign (vw->ed->rp, extract (doc, "body"));
+    if (i==0) assign (vw->ed->rp, extract (doc, "body"));
     vw->ed->set_style (buf->style);
     vw->ed->set_init  (buf->init);
     vw->ed->set_fin   (buf->fin);
@@ -212,10 +208,8 @@ tm_data_rep::revert_buffer (url name, tree doc) {
     vw->ed->add_init (buf->init);
     vw->ed->notify_change (THE_DECORATIONS);
     vw->ed->typeset_invalidate_env ();
+    vw->ed->notify_save ();
   }
-  buf->mark_undo_block ();
-  buf->need_save= buf->need_autosave= false;
-  buf->last_save= buf->last_autosave= buf->undo_depth- 1;
 }
 
 void
@@ -224,7 +218,7 @@ tm_data_rep::delete_buffer (tm_buffer buf) {
   menu_delete_buffer (buf);
   for (i=0; i<N(buf->vws); i++)
     delete_view (buf->vws[i]);
-  delete buf;
+  tm_delete (buf);
 }
 
 void
@@ -249,8 +243,10 @@ tm_data_rep::set_abbr_buffer (string abbr) {
   buf->abbr= abbr;
   for (i=0; i<N(buf->vws); i++) {
     tm_view vw2= buf->vws[i];
-    if (vw2->win != NULL)
+    if (vw2->win != NULL) {
       vw2->win->set_window_name (buf->abbr);
+      vw2->win->set_window_url (is_none (buf->extra)? buf->name: buf->extra);
+    }
   }
 }
 
@@ -286,7 +282,7 @@ tm_data_rep::new_view (url name) {
 
   tm_buffer buf= new_buffer (name);
   editor    ed = new_editor (get_server (), buf);
-  tm_view   vw = new tm_view_rep (buf, ed);
+  tm_view   vw = tm_new<tm_view_rep> (buf, ed);
   buf->vws << vw;
 
   ed->set_style (buf->style);
@@ -332,7 +328,7 @@ tm_data_rep::delete_view (tm_view vw) {
 	else a[j]= buf->vws[j+1];
       buf->vws= a;
     }
-  // delete vw;
+  // tm_delete (vw);
   // FIXME: causes very annoying segfault;
   // recently introduced during reorganization
 }
@@ -343,10 +339,10 @@ tm_data_rep::attach_view (tm_window win, tm_view vw) {
   vw->win= win;
   widget wid= win->wid;
   set_canvas (wid, vw->ed);
-  if (!is_attached (wid))
-    fatal_error ("widget should be attached", "tm_data_rep::attach_view");
+  ASSERT (is_attached (wid), "widget should be attached");
   vw->ed->resume ();
   win->set_window_name (vw->buf->abbr);
+  win->set_window_url (is_none (vw->buf->extra)? vw->buf->name: vw->buf->extra);
   // cout << "View attached\n";
 }
 
@@ -357,11 +353,11 @@ tm_data_rep::detach_view (tm_view vw) {
   if (win == NULL) return;
   vw->win= NULL;
   widget wid= win->wid;
-  if (!is_attached (wid))
-    fatal_error ("widget should be attached", "tm_data_rep::attach_view");
+  ASSERT (is_attached (wid), "widget should be attached");
   vw->ed->suspend ();
   set_canvas (wid, glue_widget ());
   win->set_window_name ("TeXmacs");
+  win->set_window_url (url_none ());
   // cout << "View detached\n";
 }
 
@@ -373,7 +369,7 @@ class kill_window_command_rep: public command_rep {
 public:
   inline kill_window_command_rep () {}
   inline void apply () { exec_delayed (scheme_cmd ("(safely-kill-window)")); }
-  ostream& print (ostream& out) { return out << "kill window"; }
+  tm_ostream& print (tm_ostream& out) { return out << "kill window"; }
 };
 
 tm_window
@@ -384,8 +380,8 @@ tm_data_rep::new_window (bool map_flag, tree geom) {
   if (get_preference ("context dependent icons") == "on") mask += 4;
   if (get_preference ("user provided icons") == "on") mask += 8;
   if (get_preference ("status bar") == "on") mask += 16;
-  command quit= new kill_window_command_rep ();
-  tm_window win= new tm_window_rep (texmacs_widget (mask, quit), geom);
+  command quit= tm_new<kill_window_command_rep> ();
+  tm_window win= tm_new<tm_window_rep> (texmacs_widget (mask, quit), geom);
   if (map_flag) win->map ();
   return win;
 }
@@ -409,10 +405,10 @@ tm_data_rep::delete_view_from_window (tm_window win) {
 
 void
 tm_data_rep::delete_window (tm_window win) {
-  while (delete_view_from_window (win));
+  while (delete_view_from_window (win)) {}
   win->unmap ();
   destroy_window_widget (win->win);
-  delete win;
+  tm_delete (win);
 }
 
 /******************************************************************************
@@ -546,11 +542,9 @@ tm_data_rep::kill_buffer () {
   if (N(bufs) <= 1) quit();
   tm_buffer buf= get_buffer();
   for (nr=0; nr<N(bufs); nr++) if (buf == bufs[nr]) break;
-  if (nr == N(bufs))
-    fatal_error ("Buffer not found", "tm_data_rep::kill_buffer");
+  ASSERT (nr != N(bufs), "buffer not found");
   for (nr=0; nr<N(bufs); nr++) if (buf != bufs[nr]) break;
-  if (nr == N(bufs))
-    fatal_error ("No suitable new buffer", "tm_data_rep::kill_buffer");
+  ASSERT (nr != N(bufs), "no suitable new buffer");
   tm_buffer new_buf = bufs[nr];
 
   for (i=0; i<N(buf->vws); i++) {
@@ -625,18 +619,6 @@ tm_data_rep::kill_window_and_buffer () {
   if (kill) delete_buffer (buf);
 }
 
-void
-tm_data_rep::set_max_undo_depth (int i) {
-  if (i <  0) i= -1;
-  if (i == 0) i= 1;
-  max_undo_depth= i;
-}
-
-int
-tm_data_rep::get_max_undo_depth () {
-  return max_undo_depth;
-}
-
 bool
 tm_data_rep::no_bufs () {
   return N(bufs) == 0;
@@ -706,7 +688,7 @@ tm_data_rep::set_buffer_tree (url name, tree doc) {
   if (nr == -1) new_buffer (name, tree (DOCUMENT));
   nr= find_buffer (name);
   tm_buffer buf= bufs[nr];
-  get_editor () -> assign (buf->rp, doc);
+  assign (buf->rp, doc);
 }
 
 tree
@@ -726,10 +708,10 @@ tm_data_rep::project_attach (string prj_name) {
   int i;
   tm_buffer buf= get_buffer ();
   buf->project= prj_name;
-  buf->need_save= buf->need_autosave= true;
   for (i=0; i<N(buf->vws); i++) {
     tm_view vw= buf->vws[i];
     vw->ed->notify_change (THE_DECORATIONS);
+    vw->ed->require_save ();
   }
   if (prj_name == "") buf->prj= NULL;
   else {
@@ -749,8 +731,8 @@ tm_data_rep::get_project_buffer_menu () {
   tm_buffer buf= get_buffer ();
   if (buf->prj == NULL) return eval ("(menu-dynamic)");
   string s ("(menu-dynamic ");
-  s << "(\"" << buf->prj->abbr << "\" ";
-  s << "(switch-to-buffer \"" * as_string (buf->prj->name) * "\"))";
+  s << "(" << scm_quote (buf->prj->abbr) << " ";
+  s << "(switch-to-buffer " * scm_quote (as_string (buf->prj->name)) * "))";
 
   tree t= subtree (the_et, buf->prj->rp);
   int i, j, n= N(t);
@@ -759,8 +741,8 @@ tm_data_rep::get_project_buffer_menu () {
       string name= as_string (head (buf->prj->name) * as_string (t[i][0]));
       for (j=N(name)-1; j>=0; j--)
 	if (name[j]=='/') break;
-      s << " (\"" << name (j+1, N(name)) << "\" ";
-      s << "(switch-to-buffer \"" * name * "\"))";
+      s << " (" << scm_quote (name (j+1, N(name))) << " ";
+      s << "(switch-to-buffer " * scm_quote (name) * "))";
     }
 
   s << ")";
@@ -777,32 +759,24 @@ path
 new_document () {
   int i, n= N(the_et);
   for (i=0; i<n; i++)
-    if (the_et[i] == UNINIT && is_nil (the_et[i]->obs)) {
+    if (the_et[i] == UNINIT) {
       assign (the_et[i], tree (DOCUMENT, ""));
       return path (i); // obtain_ip (the_et[i]);
     }
   insert (the_et, n, tuple (tree (DOCUMENT, "")));
-#ifdef EXPERIMENTAL
-  global_notify_insert (path (n), tuple (tree (DOCUMENT, "")));
-#endif
   return path (n); // obtain_ip (the_et[n]);
 }
 
 void
 delete_document (path rp) {
   assign (subtree (the_et, rp), UNINIT);
-#ifdef EXPERIMENTAL
-  global_notify_assign (rp, UNINIT);
-#endif
+  clean_observers (subtree (the_et, rp));
 }
 
 void
 set_document (path rp, tree t) {
   //assign (subtree (the_et, rp), t);
   assign (subtree (the_et, rp), copy (t));
-#ifdef EXPERIMENTAL
-  global_notify_assign (rp, copy (t));
-#endif
 }
 
 /******************************************************************************
@@ -819,15 +793,15 @@ create_window_id () {
 }
 
 static path
-remove (path p, int i) {
+reset (path p, int i) {
   if (is_nil (p)) return p;
   else if (p->item == i) return p->next;
-  else return path (p->item, remove (p->next, i));
+  else return path (p->item, reset (p->next, i));
 }
 
 void
 destroy_window_id (int i) {
-  the_windows= remove (the_windows, i);
+  the_windows= reset (the_windows, i);
 }
 
 int
@@ -896,104 +870,23 @@ tm_data_rep::window_focus (int id) {
 }
 
 /******************************************************************************
-* Undo/redo routines for buffers as well as tests for (auto)saves
+* Check for changes in the buffer
 ******************************************************************************/
 
-void
-tm_buffer_rep::mark_undo_block () {
-  if ((undo == "nil") || (undo[0] != "")) {
-    undo= tree (BACKUP, "", undo);
-    undo_depth++;
-  }
-}
-
-void
-tm_buffer_rep::mark_redo_block () {
-  if ((redo == "nil") || (redo[0] != "")) {
-    redo= tree (BACKUP, "", redo);
-    exdo= tree (BACKUP, "", exdo);
-    redo_depth++;
-  }
-}
-
-void
-tm_buffer_rep::unmark_undo_block () {
-  if ((undo != "nil") && undo[0] == "") {
-    undo= undo[1];
-    undo_depth--;
-  }
-}
-
-void
-tm_buffer_rep::unmark_redo_block () {
-  if ((redo != "nil") && redo[0] == "") {
-    redo= redo[1];
-    exdo= exdo[1];
-    redo_depth--;
-  }
-}
-
-void
-tm_buffer_rep::redo_to_undo () {
-  if (redo == "nil") mark_undo_block ();
-  else {
-    tree re= redo[0];
-    tree ex= exdo[0];
-    redo= redo[1];
-    exdo= exdo[1];
-    if (re == "") redo_depth--;
-    if (ex == "") mark_undo_block ();
-    else undo= tree (BACKUP, ex, undo);
-    redo_to_undo ();
-    if (re == "") mark_undo_block ();
-    else undo= tree (BACKUP, re, undo);
-  }
-}
-
-void
-tm_buffer_rep::truncate_undos (int nr) {
-  int i;
-  tree rev= "nil";
-  for (i=0; i<nr; i++) {
-    while (undo[0] != "") {
-      rev= tree (BACKUP, undo[0], rev);
-      undo= undo[1];
-    }
-    rev= tree (BACKUP, undo[0], rev);
-    undo= undo[1];
-  }
-
-  undo= "nil";
-  for (i=0; i<nr; i++) {
-    undo= tree (BACKUP, rev[0], undo);
-    rev= rev[1];
-    while ((rev != "nil") && (rev[0] != "")) {
-      undo= tree (BACKUP, rev[0], undo);
-      rev= rev[1];
-    }
-  }
-
-  int del= undo_depth- nr;
-  undo_depth    -= del;
-  last_save     -= del;
-  last_autosave -= del;
-}
-
 bool
 tm_buffer_rep::needs_to_be_saved () {
   if (!in_menu) return false;
-  if (need_save) return true;
-  if ((undo == "nil") || (undo[0] != ""))
-    return (last_save != undo_depth);
-  else return (last_save != (undo_depth-1));
+  for (int i=0; i<N(vws); i++)
+    if (vws[i]->ed->need_save ())
+      return true;
+  return false;
 }
 
 bool
 tm_buffer_rep::needs_to_be_autosaved () {
   if (!in_menu) return false;
-  if (!needs_to_be_saved ()) return false;
-  if (need_autosave) return true;
-  if ((undo == "nil") || (undo[0] != ""))
-    return (last_autosave != undo_depth);
-  else return (last_autosave != (undo_depth-1));
+  for (int i=0; i<N(vws); i++)
+    if (vws[i]->ed->need_save (false))
+      return true;
+  return false;
 }
