@@ -161,6 +161,7 @@ void
 tm_config_rep::get_keycomb (
   string& which, int& status, command& cmd, string& shorth, string& help)
 {
+  string orig= which;
   // cout << which;
   variant_simplification (which);
   // cout << " -> " << which;
@@ -168,7 +169,7 @@ tm_config_rep::get_keycomb (
   // cout << " -> " << rew << LF;
   object obj= find_key_binding (rew);
   // cout << rew << " => " << obj << LF;
-  if (obj == object (false)) {
+  if (obj == object (false) || (orig != which && !is_string (car (obj)))) {
     status= 0;
     cmd   = command ();
     shorth= copy (rew);
