@@ -4,10 +4,9 @@
 * DESCRIPTION: Main current graphical interface for user applications
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef TM_SERVER_H
@@ -71,7 +70,6 @@ public:
   string translate (string which, string from, string to);
   bool   is_yes (string s);
   void   quit ();
-  tree   evaluate (string name, string session, tree expr);
   void   shell    (string s);
 };
 
