@@ -4,15 +4,13 @@
 * DESCRIPTION: animations
 * COPYRIGHT  : (C) 2005  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Boxes/composite.hpp"
 #include "Boxes/construct.hpp"
-#include "timer.hpp"
 #include "file.hpp"
 
 /******************************************************************************
@@ -71,6 +69,7 @@ anim_constant_box_rep::anim_constant_box_rep (path ip, box b, int length2):
 
 void
 anim_constant_box_rep::pre_display (renderer& ren) {
+  (void) ren;
   if (!started) anim_start_at (texmacs_time ());
   else if (!finished) {
     finished= (texmacs_time () - (started_at+length) >= 0);
@@ -149,9 +148,7 @@ public:
 anim_compose_box_rep::anim_compose_box_rep (path ip, array<box> bs2):
   box_rep (ip), bs (bs2), cum_len (N(bs))
 {
-  if (N(bs) == 0)
-    fatal_error ("Empty animation",
-		 "anim_compose_box_rep::anim_compose_box_rep");
+  ASSERT (N(bs) != 0, "empty animation");
 
   started = false;
   finished= false;
@@ -212,6 +209,7 @@ anim_compose_box_rep::find_tag (string name) {
 
 void
 anim_compose_box_rep::pre_display (renderer& ren) {
+  (void) ren;
   if (!started) anim_start_at (texmacs_time ());
   else if (!finished) {
     time_t now= texmacs_time ();
@@ -333,6 +331,7 @@ anim_repeat_box_rep::anim_repeat_box_rep (path ip, box b):
 
 void
 anim_repeat_box_rep::pre_display (renderer& ren) {
+  (void) ren;
   if (!started) anim_start_at (texmacs_time ());
   else if (length > 0) {
     time_t now= texmacs_time ();
@@ -511,6 +510,7 @@ struct sound_box_rep: public box_rep {
       system ("play", u, "&");
     started= true; }
   void pre_display (renderer& ren) {
+    (void) ren;
     if (!started) anim_start_at (texmacs_time ()); }
   int  anim_length () { return 0; }
   bool anim_started () { return started; }
@@ -560,32 +560,32 @@ add_frames (array<box>& a, path ip, url u, int w, int h, int msecs) {
 
 box
 anim_constant_box (path ip, box b, int len) {
-  return new anim_constant_box_rep (ip, b, len);
+  return tm_new<anim_constant_box_rep> (ip, b, len);
 }
 
 box
 anim_compose_box (path ip, array<box> bs) {
-  return new anim_compose_box_rep (ip, bs);
+  return tm_new<anim_compose_box_rep> (ip, bs);
 }
 
 box
 anim_repeat_box (path ip, box b) {
-  return new anim_repeat_box_rep (ip, b);
+  return tm_new<anim_repeat_box_rep> (ip, b);
 }
 
 box
 anim_translate_box (path ip, box b, int len, SI sx, SI sy, SI ex, SI ey) {
-  return new anim_translate_box_rep (ip, b, len, sx, sy, ex, ey);
+  return tm_new<anim_translate_box_rep> (ip, b, len, sx, sy, ex, ey);
 }
 
 box
 anim_progressive_box (path ip, box b, int len, rectangle r1, rectangle r2) {
-  return new anim_progressive_box_rep (ip, b, len, r1, r2);
+  return tm_new<anim_progressive_box_rep> (ip, b, len, r1, r2);
 }
 
 box
 sound_box (path ip, url u, SI h) {
-  return new sound_box_rep (ip, u, h);
+  return tm_new<sound_box_rep> (ip, u, h);
 }
 
 box
