@@ -4,17 +4,15 @@
 * DESCRIPTION: Important routines for all boxes
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boxes.hpp"
 #include "formatter.hpp"
 #include "Graphics/point.hpp"
-#include "timer.hpp"
-#include "PsDevice/printer.hpp"
+#include "printer.hpp"
 #include "file.hpp"
 #include "merge_sort.hpp"
 
@@ -25,7 +23,7 @@
 int box_rep::subnr () { return 0; }
 box box_rep::subbox (int i) { (void) i; return box (); }
 box box::operator [] (path p) {
-  if (nil (p)) return *this; else return rep->subbox(p->item)[p->next]; }
+  if (is_nil (p)) return *this; else return rep->subbox(p->item)[p->next]; }
 double box_rep::left_slope () { return 0.0; }
 double box_rep::right_slope () { return 0.0; }
 SI box_rep::left_correction () { return (SI) (-min (0, y1) * left_slope ()); }
@@ -122,7 +120,7 @@ box_rep::find_box_path (path p, bool& found) {
   //      << "; " << reverse (ip)
   //      << ", " << reverse (find_lip ())
   //      << " -- " << reverse (find_rip ()) << "\n";
-  found= (!nil(p)) && is_accessible (ip);
+  found= (!is_nil(p)) && is_accessible (ip);
   if (last_item (p) == 0) return path (0);
   else return path (1);
 }
@@ -183,7 +181,7 @@ box_rep::find_check_selection (path lp, path rp) {
 void
 box_rep::relocate (path new_ip, bool force) {
   if (!force)
-    if (nil (ip) || (ip->item >= 0) || (ip == new_ip)) return;
+    if (is_nil (ip) || (ip->item >= 0) || (ip == new_ip)) return;
   ip= new_ip;
   int i, n= subnr ();
   for (i=0; i<n; i++) subbox (i)->relocate (ip, force);
@@ -209,23 +207,23 @@ find_innermost_scroll (box b, path p) {
     bp= b->find_box_path (p, found);
     if (found) break;
     p= path_up (p);
-    if (nil (p)) return path ();
+    if (is_nil (p)) return path ();
   }
   bp= path_up (bp);
   path cp, sp;
-  while (!nil (bp)) {
+  while (!is_nil (bp)) {
     if (b->get_type () == SCROLL_BOX) sp= reverse (cp);
     b = b[bp->item];
     cp= path (bp->item, cp);
     bp= bp->next;
   }
-  if (nil (sp)) return sp;
+  if (is_nil (sp)) return sp;
   else return sp * 0;
 }
 
 path
 find_scrolled_box_path (box b, path sp, SI x, SI y, SI delta) {
-  if (nil (sp)) return b->find_box_path (x, y, delta, false);
+  if (is_nil (sp)) return b->find_box_path (x, y, delta, false);
   else {
     int m= sp->item;
     SI xx= x - b->sx (m), yy= y - b->sy (m);
@@ -246,11 +244,11 @@ void
 find_canvas_info (box b, path sp, SI& x, SI& y, SI& sx, SI& sy,
 		  rectangle& outer, rectangle& inner)
 {
-  if (nil (sp)) {
+  if (is_nil (sp)) {
     x= y= sx= sy= 0;
     outer= inner= rectangle (0, 0, 0, 0);
   }
-  else if (atom (sp)) {
+  else if (is_atom (sp)) {
     x    = 0;
     y    = 0;
     sx   = b->sx (0);
@@ -290,17 +288,18 @@ box_rep::find_frame (path bp, bool last) {
   SI    y= 0;
   box   b= this;
   frame f= get_frame ();
-  while (!nil (bp)) {
+  while (!is_nil (bp)) {
     x += b->sx (bp->item);
     y += b->sy (bp->item);
     b  = b->subbox (bp->item);
     bp = bp->next;
     frame g= b->get_frame ();
-    if (!nil (g))
+    if (!is_nil (g)) {
       if (last)
 	f= g;
       else
 	f= scaling (1.0, point (x, y)) * g;
+    }
   }
   return f;
 }
@@ -309,11 +308,11 @@ grid
 box_rep::find_grid (path bp) {
   box   b= this;
   grid g= get_grid ();
-  while (!nil (bp)) {
+  while (!is_nil (bp)) {
     b  = b->subbox (bp->item);
     bp = bp->next;
     grid g2= b->get_grid ();
-    if (!nil (g2)) g= g2;
+    if (!is_nil (g2)) g= g2;
   }
   return g;
 }
@@ -322,7 +321,7 @@ void
 box_rep::find_limits (path bp, point& lim1, point& lim2) {
   box b= this;
   get_limits (lim1, lim2);
-  while (!nil (bp)) {
+  while (!is_nil (bp)) {
     point slim1, slim2;
     b  = b->subbox (bp->item);
     bp = bp->next;
@@ -395,57 +394,57 @@ box_rep::get_info (tree in) {
 int
 box_rep::get_leaf_left_pos () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_left_pos");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 int
 box_rep::get_leaf_right_pos () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_right_pos");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 string
 box_rep::get_leaf_string () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_string");
-  return ""; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return "";
 }
 
 font
 box_rep::get_leaf_font () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_font");
-  return font (); // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return font ();
 }
 
 color
 box_rep::get_leaf_color () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_color");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 language
 box_rep::get_leaf_language () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_language");
-  return language (); // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return language ();
 }
 
 tree
 box_rep::get_leaf_tree () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("no tree attached to this box", "get_leaf_tree");
-  return ""; // Because of bug in certain versions of g++
+  FAILED ("no tree attached to this box");
+  return "";
 }
 
 lazy
 box_rep::get_leaf_lazy () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("no lazy attached to this box", "get_leaf_lazy");
-  return lazy (); // Because of bug in certain versions of g++
+  FAILED ("no lazy attached to this box");
+  return lazy ();
 }
 
 SI
@@ -461,11 +460,11 @@ box_rep::get_leaf_offset (string search) {
 int nr_painted= 0;
 
 void
-clear_pattern_rectangles (ps_device dev, rectangles l) {
-  while (!nil (l)) {
+clear_pattern_rectangles (renderer ren, rectangles l) {
+  while (!is_nil (l)) {
     rectangle r (l->item);
-    dev->clear_pattern (r->x1- dev->ox, r->y1- dev->oy,
-			r->x2- dev->ox, r->y2- dev->oy);
+    ren->clear_pattern (r->x1- ren->ox, r->y1- ren->oy,
+			r->x2- ren->ox, r->y2- ren->oy);
     l= l->next;
   }
 }
@@ -485,26 +484,26 @@ box_rep::reindex (int i, int item, int n) {
 }
 
 void
-box_rep::redraw (ps_device dev, path p, rectangles& l) {
-  if (((nr_painted&15) == 15) && dev->interrupted (true)) return;
-  dev->move_origin (x0, y0);
-  SI delta= dev->pixel; // adjust visibility to compensate truncation
-  if (dev->is_visible (x3- delta, y3- delta, x4+ delta, y4+ delta)) {
+box_rep::redraw (renderer ren, path p, rectangles& l) {
+  if (((nr_painted&15) == 15) && ren->interrupted (true)) return;
+  ren->move_origin (x0, y0);
+  SI delta= ren->pixel; // adjust visibility to compensate truncation
+  if (ren->is_visible (x3- delta, y3- delta, x4+ delta, y4+ delta)) {
     rectangles ll;
     l= rectangles();
-    pre_display (dev);
+    pre_display (ren);
 
     int i, item=-1, n=subnr (), i1= n, i2= -1;
-    if (!nil(p)) i1= i2= item= p->item;
+    if (!is_nil(p)) i1= i2= item= p->item;
     for (i=0; i<n; i++) {
       int k= reindex (i, item, n-1);
-      if (nil(p)) subbox (k)->redraw (dev, path (), ll);
+      if (is_nil(p)) subbox (k)->redraw (ren, path (), ll);
       else if (i!=0) {
-	if (k > item) subbox(k)->redraw (dev, path (0), ll);
-	else subbox(k)->redraw (dev, path (subbox(k)->subnr()-1), ll);
+	if (k > item) subbox(k)->redraw (ren, path (0), ll);
+	else subbox(k)->redraw (ren, path (subbox(k)->subnr()-1), ll);
       }
-      else subbox(k)->redraw (dev, p->next, ll);
-      if (!nil(ll)) {
+      else subbox(k)->redraw (ren, p->next, ll);
+      if (!is_nil(ll)) {
 	i1= min (i1, k);
 	i2= max (i2, k);
 	l = ll * l;
@@ -512,28 +511,28 @@ box_rep::redraw (ps_device dev, path p, rectangles& l) {
       }
     }
 
-    if (((nr_painted&15) == 15) && dev->interrupted ()) {
-      l= translate (l, -dev->ox, -dev->oy);
-      clear_incomplete (l, dev->pixel, item, i1, i2);
-      l= translate (l, dev->ox, dev->oy);
+    if (((nr_painted&15) == 15) && ren->interrupted ()) {
+      l= translate (l, -ren->ox, -ren->oy);
+      clear_incomplete (l, ren->pixel, item, i1, i2);
+      l= translate (l, ren->ox, ren->oy);
     }
     else {
-      l= rectangle (x3+ dev->ox, y3+ dev->oy, x4+ dev->ox, y4+ dev->oy);
-      display (dev);
-      if (nr_painted < 15) dev->apply_shadow (x1, y1, x2, y2);
+      l= rectangle (x3+ ren->ox, y3+ ren->oy, x4+ ren->ox, y4+ ren->oy);
+      display (ren);
+      if (nr_painted < 15) ren->apply_shadow (x1, y1, x2, y2);
       nr_painted++;
     }
 
-    post_display (dev);
+    post_display (ren);
   }
-  dev->move_origin (-x0, -y0);
+  ren->move_origin (-x0, -y0);
 }
 
 void
-box_rep::redraw (ps_device dev, path p, rectangles& l, SI x, SI y) {
-  dev->move_origin (x, y);
-  redraw (dev, p, l);
-  dev->move_origin (-x, -y);
+box_rep::redraw (renderer ren, path p, rectangles& l, SI x, SI y) {
+  ren->move_origin (x, y);
+  redraw (ren, p, l);
+  ren->move_origin (-x, -y);
 }
 
 void
@@ -542,13 +541,13 @@ box_rep::clear_incomplete (rectangles& rs, SI pixel, int i, int i1, int i2) {
 }
 
 void
-box_rep::pre_display (ps_device &dev) {
-  (void) dev;
+box_rep::pre_display (renderer &ren) {
+  (void) ren;
 }
 
 void
-box_rep::post_display (ps_device &dev) {
-  (void) dev;
+box_rep::post_display (renderer &ren) {
+  (void) ren;
 }
 
 /******************************************************************************
@@ -556,7 +555,7 @@ box_rep::post_display (ps_device &dev) {
 ******************************************************************************/
 
 cursor::cursor (SI x, SI y, SI delta, SI y1, SI y2, double slope, bool valid):
-  rep (new cursor_rep)
+  rep (tm_new<cursor_rep> ())
 {
   rep->ox= x ; rep->oy= y ; rep->delta= delta;
   rep->y1= y1; rep->y2= y2; rep->slope= slope;
@@ -583,8 +582,8 @@ operator != (cursor cu1, cursor cu2) {
   return ! (cu1 == cu2);
 }
 
-ostream&
-operator << (ostream& out, cursor cu) {
+tm_ostream&
+operator << (tm_ostream& out, cursor cu) {
   out << "cursor (" << (cu->ox>>8) << ", " << (cu->oy>>8) << ": "
       << cu->delta << ": "
       << (cu->y1>>8) << ", " << (cu->y2>>8) << ": "
@@ -597,7 +596,7 @@ operator << (ostream& out, cursor cu) {
 ******************************************************************************/
 
 selection::selection (rectangles rs, path start, path end, bool valid):
-  rep (new selection_rep)
+  rep (tm_new<selection_rep> ())
 {
   rep->rs   = rs;
   rep->start= start;
@@ -617,8 +616,8 @@ operator != (selection sel1, selection sel2) {
   return !(sel1 == sel2);
 }
 
-ostream&
-operator << (ostream& out, selection sel) {
+tm_ostream&
+operator << (tm_ostream& out, selection sel) {
   return out << "selection (" << sel->start << ", " << sel->end << ")";
 }
 
@@ -627,14 +626,14 @@ operator << (ostream& out, selection sel) {
 ******************************************************************************/
 
 gr_selection::gr_selection (array<path> cp, SI dist):
-  rep (new gr_selection_rep)
+  rep (tm_new<gr_selection_rep> ())
 {
   rep->cp  = cp;
   rep->dist= dist;
 }
 
-ostream&
-operator << (ostream& out, gr_selection sel) {
+tm_ostream&
+operator << (tm_ostream& out, gr_selection sel) {
   return out << "gr_selection (" << sel->dist << ", " << sel->cp << ")";
 }
 
@@ -699,7 +698,7 @@ box_rep::anim_finish_now () {
 
 time_t
 box_rep::anim_next_update () {
-  fatal_error ("Invalid situation", "box_rep::anim_next_update");
+  FAILED ("invalid situation");
   return texmacs_time ();
 }
 
@@ -778,11 +777,11 @@ bool box::operator == (box b2) { return rep==b2.rep; }
 bool box::operator != (box b2) { return rep!=b2.rep; }
 
 box::operator tree () { return tree (*rep); }
-ostream& operator << (ostream& out, box b) { return out << ((tree) b); }
+tm_ostream& operator << (tm_ostream& out, box b) { return out << ((tree) b); }
 
 path
 descend_decode (path ip, int side) {
-  if (nil (ip)) return descend (ip, side);
+  if (is_nil (ip)) return descend (ip, side);
   else switch (ip->item) {
   case DECORATION       : return ip->next;
   case DECORATION_LEFT  : return descend (ip->next, 0);
@@ -816,17 +815,17 @@ attach_dip (tree ref, path dip) {
 ******************************************************************************/
 
 void
-make_eps (url name, display dis, box b, int dpi) {
+make_eps (url name, box b, int dpi) {
   double inch= ((double) dpi * PIXEL);
   double cm  = inch / 2.54;
   SI w= b->x4 - b->x3;
   SI h= b->y4 - b->y3;
   b->x0= -b->x3;
   b->y0= -b->y4;
-  ps_device dev= printer (dis, name, dpi, 1, "user", false, w/cm, h/cm);
-  dev->set_color (dis->black);
-  dev->set_background (dis->white);
+  renderer ren= printer (name, dpi, 1, "user", false, w/cm, h/cm);
+  ren->set_color (black);
+  ren->set_background (white);
   rectangles rs;
-  b->redraw (dev, path (0), rs);
-  delete dev;
+  b->redraw (ren, path (0), rs);
+  tm_delete (ren);
 }
