@@ -4,10 +4,9 @@
 * DESCRIPTION: Boxes whose behaviour is changed
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Boxes/composite.hpp"
@@ -166,8 +165,8 @@ public:
     if (in == "scroll-x") return xt;
     else if (in == "scroll-y") return yt;
     else return box_rep::get_info (in); }
-  void pre_display (ps_device &dev);
-  void post_display (ps_device &dev);
+  void pre_display (renderer &ren);
+  void post_display (renderer &ren);
   selection find_selection (path lbp, path rbp);
 };
 
@@ -185,14 +184,14 @@ clip_box_rep::clip_box_rep (
 }
 
 void
-clip_box_rep::pre_display (ps_device &dev) {
-  dev->get_clipping (old_clip_x1, old_clip_y1, old_clip_x2, old_clip_y2);
-  dev->extra_clipping (x1, y1, x2, y2);
+clip_box_rep::pre_display (renderer &ren) {
+  ren->get_clipping (old_clip_x1, old_clip_y1, old_clip_x2, old_clip_y2);
+  ren->extra_clipping (x1, y1, x2, y2);
 }
 
 void
-clip_box_rep::post_display (ps_device &dev) {
-  dev->set_clipping (
+clip_box_rep::post_display (renderer &ren) {
+  ren->set_clipping (
     old_clip_x1, old_clip_y1, old_clip_x2, old_clip_y2, true);
 }
 
@@ -247,9 +246,9 @@ struct cell_box_rep: public change_box_rep {
   cell_box_rep (path ip, box b, SI x0, SI y0, SI x1, SI y1, SI x2, SI y2,
 		SI bl, SI br, SI bb, SI bt, color fg, tree bg);
   operator tree () { return tree (TUPLE, "cell", (tree) bs[0]); }
-  void pre_display (ps_device &dev);
-  void post_display (ps_device &dev);
-  void display (ps_device dev);
+  void pre_display (renderer &ren);
+  void post_display (renderer &ren);
+  void display (renderer ren);
 };
 
 cell_box_rep::cell_box_rep (
@@ -274,25 +273,25 @@ cell_box_rep::cell_box_rep (
 }
 
 void
-cell_box_rep::pre_display (ps_device& dev) {
+cell_box_rep::pre_display (renderer& ren) {
   if (bg == "") return;
-  old_bg= dev->get_background_pattern ();
-  dev->set_background_pattern (bg);
-  dev->clear_pattern (x1, y1, x2, y2);
+  old_bg= ren->get_background_pattern ();
+  ren->set_background_pattern (bg);
+  ren->clear_pattern (x1, y1, x2, y2);
 }
 
 void
-cell_box_rep::post_display (ps_device &dev) {
+cell_box_rep::post_display (renderer &ren) {
   if (bg == "") return;
-  dev->set_background_pattern (old_bg);
+  ren->set_background_pattern (old_bg);
 }
 
 void
-cell_box_rep::display (ps_device dev) {
+cell_box_rep::display (renderer ren) {
   if ((bl>0) || (br>0) || (bb>0) || (bt>0)) {
     SI l= bl, r= br, b= bb, t= bt;
-    if (dev->sfactor > 1) { // correction for screen display only
-      SI  pixel= dev->pixel;
+    if (ren->sfactor > 1) { // correction for screen display only
+      SI  pixel= ren->pixel;
       l= ((l + (pixel - 1)) / pixel) * pixel;
       r= ((r + (pixel - 1)) / pixel) * pixel;
       b= ((b + (pixel - 1)) / pixel) * pixel;
@@ -300,11 +299,11 @@ cell_box_rep::display (ps_device dev) {
     }
     SI X1= x1-(l>>1), X2= x2+(r>>1);
     SI Y1= y1-(b>>1), Y2= y2+(t>>1);
-    dev->set_color (fg);
-    dev->fill (X1  , Y1  , X1+l, Y2  );
-    dev->fill (X2-r, Y1  , X2  , Y2  );
-    dev->fill (X1  , Y1  , X2  , Y1+b);
-    dev->fill (X1  , Y2-t, X2  , Y2  );
+    ren->set_color (fg);
+    ren->fill (X1  , Y1  , X1+l, Y2  );
+    ren->fill (X2-r, Y1  , X2  , Y2  );
+    ren->fill (X1  , Y1  , X2  , Y1+b);
+    ren->fill (X1  , Y2-t, X2  , Y2  );
   }
 }
 
@@ -340,8 +339,8 @@ public:
     logs= rectangles (rectangle (ox+x3, oy+y3, ox+x4, oy+y4), logs);
     logs_ptr= &logs;
   }
-  inline void display (ps_device dev) {
-    dev->apply_shadow (x1, y1, x2, y2);
+  inline void display (renderer ren) {
+    ren->apply_shadow (x1, y1, x2, y2);
   }
 };
 
@@ -356,9 +355,9 @@ struct highlight_box_rep: public change_box_rep {
   highlight_box_rep (path ip, box b, SI w, SI xpad, SI ypad,
 		     tree bg, color sun, color shad);
   operator tree () { return tree (TUPLE, "highlight", (tree) bs[0]); }
-  void pre_display (ps_device &dev);
-  void post_display (ps_device &dev);
-  void display (ps_device dev);
+  void pre_display (renderer &ren);
+  void post_display (renderer &ren);
+  void display (renderer ren);
 };
 
 highlight_box_rep::highlight_box_rep (
@@ -380,37 +379,37 @@ highlight_box_rep::highlight_box_rep (
 }
 
 void
-highlight_box_rep::pre_display (ps_device& dev) {
-  old_bg= dev->get_background_pattern ();
-  dev->set_background_pattern (bg);
+highlight_box_rep::pre_display (renderer& ren) {
+  old_bg= ren->get_background_pattern ();
+  ren->set_background_pattern (bg);
   SI W= w;
-  if (!dev->is_printer ()) {
-    SI pixel= dev->pixel;
+  if (!ren->is_printer ()) {
+    SI pixel= ren->pixel;
     W= ((w + pixel - 1) / pixel) * pixel;
   }
-  dev->clear_pattern (x1+W, y1+W, x2-W, y2-W);
+  ren->clear_pattern (x1+W, y1+W, x2-W, y2-W);
 }
 
 void
-highlight_box_rep::post_display (ps_device &dev) {
-  dev->set_background_pattern (old_bg);
+highlight_box_rep::post_display (renderer &ren) {
+  ren->set_background_pattern (old_bg);
 }
 
 void
-highlight_box_rep::display (ps_device dev) {
+highlight_box_rep::display (renderer ren) {
   SI W= w;
-  if (!dev->is_printer ()) {
-    SI pixel= dev->pixel;
+  if (!ren->is_printer ()) {
+    SI pixel= ren->pixel;
     W= ((w + pixel - 1) / pixel) * pixel;
   }
-  dev->set_color (sun);
-  dev->fill (x1  , y2-W, x2  , y2  );
-  dev->fill (x1  , y1  , x1+W, y2  );
-  dev->set_color (shad);
-  dev->fill (x1+W, y1  , x2  , y1+W);
-  dev->fill (x2-W, y1  , x2  , y2-W);
-  dev->triangle (x1, y1, x1+W, y1, x1+W, y1+W);
-  dev->triangle (x2, y2, x2, y2-W, x2-W, y2-W);
+  ren->set_color (sun);
+  ren->fill (x1  , y2-W, x2  , y2  );
+  ren->fill (x1  , y1  , x1+W, y2  );
+  ren->set_color (shad);
+  ren->fill (x1+W, y1  , x2  , y1+W);
+  ren->fill (x2-W, y1  , x2  , y2-W);
+  ren->triangle (x1, y1, x1+W, y1, x1+W, y1+W);
+  ren->triangle (x2, y2, x2, y2-W, x2-W, y2-W);
 }
 
 /******************************************************************************
@@ -544,77 +543,77 @@ textat_box_rep::graphical_select (SI x, SI y, SI dist) {
 
 box
 move_box (path ip, box b, SI x, SI y, bool child_flag, bool big_flag) {
-  return new move_box_rep (ip, b, x, y, child_flag, big_flag);
+  return tm_new<move_box_rep> (ip, b, x, y, child_flag, big_flag);
 }
 
 box
 resize_box (path ip, box b, SI x1, SI y1, SI x2, SI y2,
 	    bool child_flag, bool adjust) {
-  return new resize_box_rep (ip, b, x1, y1, x2, y2, child_flag, adjust);
+  return tm_new<resize_box_rep> (ip, b, x1, y1, x2, y2, child_flag, adjust);
 }
 
 box
 clip_box (path ip, box b, SI x1, SI y1, SI x2, SI y2) {
-  return new clip_box_rep (ip, b, x1, y1, x2, y2, UNINIT, UNINIT, 0, 0);
+  return tm_new<clip_box_rep> (ip, b, x1, y1, x2, y2, UNINIT, UNINIT, 0, 0);
 }
 
 box
 clip_box (path ip, box b, SI x1, SI y1, SI x2, SI y2,
 	  tree xt, tree yt, SI scx, SI scy) {
-  return new clip_box_rep (ip, b, x1, y1, x2, y2, xt, yt, scx, scy);
+  return tm_new<clip_box_rep> (ip, b, x1, y1, x2, y2, xt, yt, scx, scy);
 }
 
 box
 vcorrect_box (path ip, box b, SI top_cor, SI bot_cor) {
-  return new vcorrect_box_rep (ip, b, top_cor, bot_cor);
+  return tm_new<vcorrect_box_rep> (ip, b, top_cor, bot_cor);
 }
 
 box
 repeat_box (path ip, box ref, box repeat, SI xoff) {
-  return new repeat_box_rep (ip, ref, repeat, xoff);
+  return tm_new<repeat_box_rep> (ip, ref, repeat, xoff);
 }
 
 box
 cell_box (path ip, box b, SI x0, SI y0, SI x1, SI y1, SI x2, SI y2,
 	  SI bl, SI br, SI bb, SI bt, color fg, tree bg)
 {
-  box cb= new cell_box_rep (ip, b, x0, y0, x1, y1, x2, y2,
+  box cb= tm_new<cell_box_rep> (ip, b, x0, y0, x1, y1, x2, y2,
 			    bl, br, bb, bt, fg, bg);
   return cb;
 }
 
 box
 remember_box (path ip, box b) {
-  return new remember_box_rep (ip, b);
+  return tm_new<remember_box_rep> (ip, b);
 }
 
 box
 highlight_box (path ip, box b, SI w, SI xpad, SI ypad,
 	       tree bg, color sun, color shad) {
-  return new highlight_box_rep (ip, b, w, xpad, ypad, bg, sun, shad);
+  return tm_new<highlight_box_rep> (ip, b, w, xpad, ypad, bg, sun, shad);
 }
 
 box
 action_box (path ip, box b, tree filter, command cmd, bool ch, path vip) {
-  return new action_box_rep (ip, b, filter, cmd, ch, vip);
+  return tm_new<action_box_rep> (ip, b, filter, cmd, ch, vip);
 }
 
 box
 action_box (path ip, box b, tree filter, command cmd, bool ch) {
-  return new action_box_rep (ip, b, filter, cmd, ch, decorate ());
+  return tm_new<action_box_rep> (ip, b, filter, cmd, ch, decorate ());
 }
 
 box
 locus_box (path ip, box b, list<string> ids, SI pixel) {
-  return new locus_box_rep (ip, b, ids, pixel);
+  return tm_new<locus_box_rep> (ip, b, ids, pixel);
 }
 
 box
 tag_box (path ip, box b, tree keys) {
-  return new tag_box_rep (ip, b, keys);
+  return tm_new<tag_box_rep> (ip, b, keys);
 }
 
 box
 textat_box (path ip, box b, SI x, SI y) {
-  return new textat_box_rep (ip, b, x, y);
+  return tm_new<textat_box_rep> (ip, b, x, y);
 }
