@@ -4,10 +4,9 @@
 * DESCRIPTION: construction routines for graphical boxes
 * COPYRIGHT  : (C) 2003  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef GRAPHICS_H
@@ -16,7 +15,7 @@
 #include "Graphics/frame.hpp"
 #include "Graphics/curve.hpp"
 #include "Graphics/grid.hpp"
-#include "display.hpp"
+#include "gui.hpp"
 
 box graphics_box (
   path ip, array<box> bs, frame f, grid g, point lim1, point lim2);
