@@ -4,10 +4,9 @@
 * DESCRIPTION: Implementation of the main TeXmacs typesetting routines
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Bridge/impl_typesetter.hpp"
@@ -27,12 +26,12 @@ typesetter_rep::typesetter_rep (edit_env& env2, tree et, path ip):
 
 typesetter
 new_typesetter (edit_env& env, tree et, path ip) {
-  return new typesetter_rep (env, et, ip);
+  return tm_new<typesetter_rep> (env, et, ip);
 }
 
 void
 delete_typesetter (typesetter ttt) {
-  delete ttt;
+  tm_delete (ttt);
 }
 
 /******************************************************************************
@@ -109,7 +108,7 @@ typesetter_rep::local_end (array<page_item>& prev_l, stack_border& prev_sb) {
 static rectangles
 requires_update (rectangles log) {
   rectangles rs;
-  while (!nil (log)) {
+  while (!is_nil (log)) {
     rectangle r1= log->item;
     rectangle r2= log->next->item;
     if (r1 == rectangle (0, 0, 0, 0)) rs= rectangles (r2, rs);
@@ -160,10 +159,10 @@ typesetter_rep::typeset () {
   // Typeset
   if (env->complete) env->local_aux= hashmap<string,tree> (UNINIT);
   br->typeset (PROCESSED+ WANTED_PARAGRAPH);
-  pager ppp= new pager_rep (br->ip, env, l);
+  pager ppp= tm_new<pager_rep> (br->ip, env, l);
   box b= ppp->make_pages ();
   if (env->complete && paper) determine_page_references (b);
-  delete ppp;
+  tm_delete (ppp);
   env->complete= false;
 
   return b;
@@ -177,7 +176,7 @@ typesetter_rep::typeset (SI& x1b, SI& y1b, SI& x2b, SI& y2b) {
   b->position_at (0, 0, change_log);
   change_log= requires_update (change_log);
   rectangle r (0, 0, 0, 0);
-  if (!nil (change_log)) r= least_upper_bound (change_log);
+  if (!is_nil (change_log)) r= least_upper_bound (change_log);
   x1b= r->x1; y1b= r->y1; x2b= r->x2; y2b= r->y2;
   change_log= rectangles ();
   return b;
@@ -190,7 +189,7 @@ typesetter_rep::typeset (SI& x1b, SI& y1b, SI& x2b, SI& y2b) {
 void
 notify_assign (typesetter ttt, path p, tree u) {
   // cout << "Assign " << p << ", " << u << "\n";
-  if (nil (p)) ttt->br= make_bridge (ttt, u, ttt->br->ip);
+  if (is_nil (p)) ttt->br= make_bridge (ttt, u, ttt->br->ip);
   else ttt->br->notify_assign (p, u);
 }
 
