@@ -4,10 +4,9 @@
 * DESCRIPTION: Typesetting textual markup
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "concater.hpp"
@@ -30,7 +29,7 @@ void
 concater_rep::typeset_colored_substring
   (string s, path ip, int pos, string col)
 {
-  color c= (col == ""? env->col: env->dis->get_color (col));
+  color c= (col == ""? env->col: named_color (col));
   box b= text_box (ip, pos, s, env->fn, c);
   a << line_item (STRING_ITEM, b, HYPH_INVALID, env->lan);
 }
@@ -317,7 +316,7 @@ concater_rep::typeset_float (tree t, path ip) {
   lazy lz= make_lazy_vstream (env, t[2], descend (ip, 2), ch);
   marker (descend (ip, 0));
   if (is_accessible (ip) && !env->read_only)
-    flag_ok (as_string (t1), decorate_middle (ip), env->dis->brown);
+    flag_ok (as_string (t1), decorate_middle (ip), brown);
   print (FLOAT_ITEM, control_box (decorate_middle (ip), lz, env->fn));
   marker (descend (ip, 1));
 }
@@ -359,7 +358,7 @@ void
 concater_rep::typeset_decorated_box (tree t, path ip) {
   (void) t; (void) ip;
   int n= N (env->decorated_boxes);
-  if ((n > 0) && (!nil (env->decorated_boxes [n-1]))) {
+  if ((n > 0) && (!is_nil (env->decorated_boxes [n-1]))) {
     print (STD_ITEM, env->decorated_boxes [n-1]);
     env->decorated_boxes [n-1]= box ();
   }
