@@ -4,10 +4,9 @@
 * DESCRIPTION: the environment of the math_editor
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
@@ -52,7 +51,7 @@ edit_env::edit_env (drd_info& drd,
 		    hashmap<string,tree>& global_ref,
 		    hashmap<string,tree>& local_aux,
 		    hashmap<string,tree>& global_aux):
-  rep (new edit_env_rep (drd, base_file_name,
+  rep (tm_new<edit_env_rep> (drd, base_file_name,
 			 local_ref, global_ref, local_aux, global_aux)) {}
 
 void
@@ -172,7 +171,7 @@ edit_env_rep::local_end (hashmap<string,tree>& prev_back) {
   back= prev_back;
 }
 
-ostream&
-operator << (ostream& out, edit_env env) {
+tm_ostream&
+operator << (tm_ostream& out, edit_env env) {
   return out << env->env;
 }
