@@ -4,14 +4,13 @@
 * DESCRIPTION: attaching numerical values to the environment variables
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
-#include "PsDevice/page_type.hpp"
+#include "page_type.hpp"
 #include "typesetter.hpp"
 
 /******************************************************************************
@@ -249,20 +248,17 @@ edit_env_rep::update_font () {
   switch (mode) {
   case 0:
   case 1:
-    fn= find_font (dis,
-		   get_string (FONT), get_string (FONT_FAMILY),
+    fn= find_font (get_string (FONT), get_string (FONT_FAMILY),
 		   get_string (FONT_SERIES), get_string (FONT_SHAPE),
 		   script (fn_size, index_level), (int) (magn*dpi));
     break;
   case 2:
-    fn= find_font (dis,
-		   get_string (MATH_FONT), get_string (MATH_FONT_FAMILY),
+    fn= find_font (get_string (MATH_FONT), get_string (MATH_FONT_FAMILY),
 		   get_string (MATH_FONT_SERIES), get_string (MATH_FONT_SHAPE),
 		   script (fn_size, index_level), (int) (magn*dpi));
     break;
   case 3:
-    fn= find_font (dis,
-		   get_string (PROG_FONT), get_string (PROG_FONT_FAMILY),
+    fn= find_font (get_string (PROG_FONT), get_string (PROG_FONT_FAMILY),
 		   get_string (PROG_FONT_SERIES), get_string (PROG_FONT_SHAPE),
 		   script (fn_size, index_level), (int) (magn*dpi));
     break;
@@ -281,8 +277,8 @@ edit_env_rep::update_color () {
     if (fc == "none") fill_mode= FILL_MODE_NONE;
     else fill_mode= FILL_MODE_BOTH;
   }
-  col= dis->get_color (c);
-  fill_color= dis->get_color (fc);
+  col= named_color (c);
+  fill_color= named_color (fc);
 }
 
 void
@@ -403,7 +399,7 @@ edit_env_rep::update_dash_style () {
   dash_style= array<bool>(0);
   if (is_string (t)) {
     string s= as_string (t);
-    if (s == "none") ;
+    if (s == "none") {}
   }
   else
   if (is_tuple (t)) {
@@ -432,7 +428,7 @@ edit_env_rep::update_line_arrows () {
   line_arrows= array<box>(2);
   if (is_string (t)) {
     string s= as_string (t);
-    if (s == "none") ;
+    if (s == "none") {}
   }
   else
   if (is_tuple (t) && N(t)<=2 && N(t)>0) {
