@@ -16,6 +16,7 @@
 #include "rectangles.hpp"
 #include "path.hpp"
 #include "renderer.hpp"
+#include "timer.hpp"
 #include "font.hpp"
 #include "language.hpp"
 #include "hashmap.hpp"
@@ -54,7 +55,7 @@ CONCRETE_CODE(cursor);
 cursor copy (cursor cu);
 bool operator == (cursor cu1, cursor cu2);
 bool operator != (cursor cu1, cursor cu2);
-ostream& operator << (ostream& out, cursor cu);
+tm_ostream& operator << (tm_ostream& out, cursor cu);
 
 /******************************************************************************
 * The selection class
@@ -77,7 +78,7 @@ CONCRETE_CODE(selection);
 
 bool operator == (selection sel1, selection sel2);
 bool operator != (selection sel1, selection sel2);
-ostream& operator << (ostream& out, selection sel);
+tm_ostream& operator << (tm_ostream& out, selection sel);
 
 /******************************************************************************
 * The graphical selection class
@@ -89,7 +90,7 @@ struct gr_selection {
   gr_selection (array<path> cp= array<path> (), SI dist= 0);
 };
 
-ostream& operator << (ostream& out, gr_selection sel);
+tm_ostream& operator << (tm_ostream& out, gr_selection sel);
 
 typedef array<gr_selection> gr_selections;
 tree as_tree (gr_selections sels);
@@ -255,8 +256,8 @@ ABSTRACT_NULL_CODE(box);
 extern int box_count;
 inline box_rep::box_rep (path ip2):
   x0(0), y0(0), x1(0), y1(0), x2(0), y2(0), x3(0), y3(0), x4(0), y4(0),
-  ip (ip2) { DEBUG(box_count++); }
-inline box_rep::~box_rep () { DEBUG(box_count--); }
+  ip (ip2) { TM_DEBUG(box_count++); }
+inline box_rep::~box_rep () { TM_DEBUG(box_count--); }
 inline bool box_rep::test_in (SI x, SI y) {
   return (x>=x1) && (x<x2) && (y>=y1) && (y<y2); }
 inline SI box_rep::w () { return x2-x1; }
@@ -274,7 +275,7 @@ inline SI box_rep::sy4 (int i) { box b= subbox(i); return b->y0+ b->y4; }
 
 inline box box::operator [] (int i) { return rep->subbox(i); }
 inline int N (box b) { return b.rep->subnr(); }
-ostream& operator << (ostream& out, box b);
+tm_ostream& operator << (tm_ostream& out, box b);
 SI   get_delta (SI x, SI x1, SI x2);
 bool outside (SI x, SI delta, SI x1, SI x2);
 void make_eps (url dest, box b, int dpi);
